@@ -77,42 +77,50 @@ var shared_doc = {
     "A uniform position-specific prior is used."
   ],
 
+  /* psp alpha */
+  "all-psp_alpha-opt": ["alpha"],
+  "all-psp_alpha-val": ["num"],
+  "all-psp_alpha-desc": [
+    "The alpha parameter for calculating position-specific priors, used in conjunction with the ",
+    "<span class='popt'>",
+    {"if": "ddash", "yes": "-"},
+    "-psp</span> option. <span class='pdat'>num</span> represents the fraction of all transcription ",
+    "factor binding sites that are binding sites for the TF of interest. ",
+    "<span class='pdat'>num</span> must be between 0 and 1."
+  ], 
+  "all-psp_alpha-def": [
+    "A value of 1.0 is used."
+  ],
+
   /* prior-dist */
   "all-pdist-opt": ["prior-dist"],
   "all-pdist-val": ["file"],
   "all-pdist-desc": [
      "File containing binned distribution of priors. ",
      "This file can be generated using the ",
-     "<a href='create-priors.html'>create-priors</a> utility."
+     "<a href='create-priors.html'>create-priors</a> utility. ",
+     "This option is required if the option ",
+     "<span class='popt'>",
+      {"if": "ddash", "yes": "-"},
+      "-psp</span> is specified."
   ],
   "all-pdist-def": [
-    "A uniform position-specific prior is used."
+    "None."
   ],
 
 
   /* parse-genomic-coord */
   "all-pgc-opt": ["parse-genomic-coord"],
   "all-pgc-desc": [
-    "When this option is specified, each FASTA sequence header is ",
-    "checked for UCSC style genomic coordinates (e.g., <code>chr1:156887119-156887619</code>). ",
-    "The sequence ID in the FASTA header should have the form:",
-    "<div style='margin: 5px 0'>",
-    "  &gt;<span class='pdat'>sequence name</span>:<span class='pdat'",
-    "  >starting position</span>-<span class='pdat'>ending position</span>",
-    "</div>",
-    "Where",
-    "<ul style='margin-top: 0; margin-bottom: 5px'>",
-    "  <li><span class='pdat'>sequence name</span> is the name of the sequence,</li>",
-    "  <li><span class='pdat'>starting position</span> is the genomic position of the first base and</li>",
-    "  <li><span class='pdat'>ending position</span> is the genomic position of the final base.</li>",
-    "</ul>",
-    "The <span class='pdat'>sequence name</span> may not contain any white space. ",
-    "If genomic coordinates are found they is used as the ",
-    "coordinates in the output. When no coordinates are found, the default ",
-    "behavior is used."
+    "Show actual sequence coordinates for motif sites in the output if the FASTA ",
+    "IDs of the sequences include coordinates in an <a href=\'fasta-coordinates-format.html\'> accepted format</a>. ",
+    "When this option is specified, each input sequence FASTA header is ",
+    "checked for UCSC-style genomic coordinates (e.g., <code>chr1:156887119-156887619</code>) or ",
+    "Galaxy 'Fetch sequence'-style coordinates (e.g., <code>>mm9_chr18_75759530_7575972_-</code>). ",
+    "The strand (if given) is ignored."
   ],
   "all-pgc-def": [
-    "The first position in the sequence is assumed to be 1."
+    "The first position in the sequence is assumed to be position 1."
   ],
 
   /* inc */
@@ -173,7 +181,7 @@ var shared_doc = {
       "yes": "The frequencies of the letters in the (primary) <b>sequences</b> are used as the 0-order background model.",
       "no": [ 
         {"if": "dna_only",
-          "yes": "Frequencies embedded in the application (from an early version of the non-redundant DNA) are used.", 
+          "yes": "Frequencies embedded in the application (from an early version of the non-redundant DNA database) are used.", 
           "no": "If the sequence alphabet is DNA or protein, frequencies embedded in the application (from an early version of the non-redundant DNA or protein database, respectively) are used. Otherwise, the letter frequencies contained in the motif file are used."
         }
       ]
