@@ -258,7 +258,7 @@ function make_other_settings() {
   $("opt_threshold_type").textContent = thresh_type;
   $("opt_threshold_value").textContent = thresh_value;
   $("opt_parse_genomic_coord").textContent = (data.settings.genomic_coord ? "Yes" : "No");
-  $("opt_synth").textContent = (data.settings.synth ? "Yes with seed " + data.settings.seed : "No");
+  $("opt_seed").textContent = data.settings.seed;
 
   // adv opts (no way of setting via mcast command line)
   $("opt_min_match_score").textContent = data.settings.min_match_score;
