@@ -163,7 +163,7 @@ function get_tgene_doc_text(doc_type, extra) {
 	this file allows interactive selection, filtering and sorting of the potential regulatory links. 
       `);
     case 'html-file':
-      return(`<p>` + get_tgene_doc("", 'html-file-short') + `</p>`);
+      return(`<p>` + get_tgene_doc_text("", 'html-file-short') + `</p>`);
     case 'tsv-general':
       return(`
 	The first line in the file contains the (tab-separated) names of the fields.
