@@ -464,7 +464,7 @@ ARRAY_T* get_mast_frequencies(ALPH_T *alph, bool has_ambigs, bool translate);
 
 /*
  * Load the non-redundant database frequencies into the array.
- * FIXME broken function, currently aliased to get_uniform_frequencies
+ * TODO: broken function, currently aliased to get_uniform_frequencies
  */
 ARRAY_T* get_nrdb_frequencies(ALPH_T *alph, ARRAY_T* freqs);
 
@@ -618,8 +618,9 @@ void translate_seq(ALPH_T *alph, char *sequence, int flags);
 /*
  * invcomp_seq
  * Converts a sequence in place to its reverse complement.
+ * Preserve case of input sequence if preserve_case is true
  */
-void invcomp_seq(ALPH_T *alph, char *sequence, long length);
+void invcomp_seq(ALPH_T *alph, char *sequence, long length, bool preserve_case);
 
 /* Check if word is a palindrome */
 bool is_palindrome(
