@@ -329,7 +329,6 @@ void search_with_model(
         get_int_sequence(sequence),
         seq_length,
         NULL,		// PSP
-        0,		// num_priors
 	0,		// PSP ALPHA
         the_log_hmm,
         &motif_score_matrix
@@ -984,7 +983,7 @@ static void process_command_line(
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
 
     // Read the next option, and break if we're done.
@@ -993,7 +992,7 @@ static void process_command_line(
       break;
     } else if (c < 0) {
       simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "bgfile") == 0) {
