@@ -8,7 +8,6 @@
 #include "utils.h"
 #include "alignment.c"
 
-#ifdef MAIN
 VERBOSE_T verbosity = NORMAL_VERBOSE;
 
 /*************************************************************************
@@ -17,21 +16,21 @@ VERBOSE_T verbosity = NORMAL_VERBOSE;
 int main(int argc, char *argv[]) {
 
   if (argc != 2) {
-    fprintf(stderr, "USAGE: clustalw2phyilip <alignment>\n");
+    fprintf(stderr, "Usage: clustalw2phyilip <clustalw file>\n");
     exit(1);
   }
   char* clustalw_filename = argv[1];
 
   // Open the file for reading.
   FILE* clustalw_file;
-  if (open_file(clustalw_filename, "r", TRUE, "CLUSTAL", "alignment", 
+  if (open_file(clustalw_filename, "r", true, "CLUSTAL", "alignment", 
         &clustalw_file) == 0) {
     exit(1);
   }
 
   // Read the alignment
   ALIGNMENT_T* alignment = NULL;
-  BOOLEAN_T result = read_clustalw(clustalw_file, &alignment);
+  bool result = read_clustalw(clustalw_file, &alignment);
   if (result) {
     print_phylip_alignment(alignment, stdout);
     free_alignment(alignment);
@@ -43,5 +42,3 @@ int main(int argc, char *argv[]) {
   fclose(clustalw_file);
   return(!result);
 }
-
-#endif
