@@ -106,7 +106,7 @@ static void process_command_line(
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -115,7 +115,7 @@ static void process_command_line(
     }
     else if (c < 0) {
       (void) simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
     if (strcmp(option_name, "alpha") == 0) {
       options->alpha = strtod(option_value, NULL);
