@@ -147,7 +147,7 @@ void em(
   // Discretize
   (void) discretize(model, dataset, neg_dataset, E_STEP);            
 
-#ifdef FIXME
+#ifdef TODO
   // Check that EM didn't wander off; starting point should be among sites.
   // TODO: Test if Classic would be improved by this step as well.
   if (dataset->objfun != Classic && s_point) {
