@@ -6,7 +6,9 @@
  * COPYRIGHT: 2004-2007, UW
  ********************************************************************/
 
+#ifdef MAIN
 #define DEFINE_GLOBALS
+#endif
 
 #include <assert.h>
 #include <stdio.h>
@@ -34,7 +36,6 @@
 #include "wiggle-reader.h"
 
 char* program_name = "fimo";
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 
 const char *threshold_type_to_string(THRESHOLD_TYPE type) {
   switch(type) {
@@ -68,7 +69,8 @@ static DATA_BLOCK_READER_T *get_psp_reader(
   else {
     psp_reader = new_prior_reader_from_psp(
         parse_genomic_coord,
-        prior_filename
+        prior_filename,
+        default_prior
       );
   }
   
@@ -130,30 +132,31 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     "Usage: fimo [options] <motif file> <sequence file>\n"
     "\n"
     "   Options:\n"
-    "     --alpha <double> (default 1.0)\n"
+    "     --o <output dir> (default: fimo_out)\n"
+    "     --oc <output dir> (default: fimo_out)\n"
+    "     --text\n"
+    "     --skip-matched-sequence\n"
+    "     --motif <id> (default: all)\n"
+    "     --motif-pseudo <float> (default: 0.1)\n"
+    "     --parse-genomic-coord\n"
     "     --bfile <background file> (DNA and protein use NRDB by default)\n"
-    "     --max-stored-scores <int> (default=100000)\n"
-    "     --max-strand\n"
-    "     --motif <id> (default=all)\n"
-    "     --motif-pseudo <float> (default=0.1)\n"
+    "     --psp <PSP filename> (default: none)\n"
+    "     --alpha <double> (default 1.0)\n"
+    "     --prior-dist <PSP distribution filename> (default: none)\n"
+    "     --thresh <float> (default: 1e-4)\n"
+    "     --qv-thresh\n"
     "     --no-qvalue\n"
     "     --norc\n"
-    "     --o <output dir> (default=fimo_out)\n"
-    "     --oc <output dir> (default=fimo_out)\n"
-    "     --parse-genomic-coord\n"
-    "     --psp <PSP filename> (default none)\n"
-    "     --prior-dist <PSP distribution filename> (default none)\n"
-    "     --qv-thresh\n"
-    "     --skip-matched-sequence\n"
-    "     --text\n"
-    "     --thresh <float> (default = 1e-4)\n"
-    "     --verbosity [1|2|3|4] (default 2)\n"
+    "     --max-strand\n"
+    "     --max-stored-scores <int> (default: 100000)\n"
     "     --version (print the version and exit)\n"
+    "     --verbosity [1|2|3|4|5] (default: 2)\n"
     "\n"
     "   When scanning with a single motif use \'-\' for <sequence file> to\n"
     "     read the database from standard input.\n"
     "   Use \'--bfile --motif--\' to read the background from the motif file.\n"
     "   Use \'--bfile --uniform--\' to use a uniform background.\n"
+    "   Use \'--bfile --nrdb--\' to use a NRDB background.\n"
     "\n";
 
   int option_index = 0;
@@ -195,7 +198,7 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -204,7 +207,7 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     }
     else if (c < 0) {
       (void) simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
     if (strcmp(option_name, "bfile") == 0 || strcmp(option_name, "bgfile") == 0){
       options.bg_filename = option_value;
@@ -452,7 +455,7 @@ static inline bool fimo_score_site(
     if (!isnan(prior)) {
     // Use the prior to adjust the motif site score.
     // Using the log-odds prior increases the width
-      // of the scaled score table by 1.
+    // of the scaled score table by 1.
       ++w;
       double prior_log_odds = (options.alpha) * prior;
       prior_log_odds = my_log2(prior_log_odds / (1.0 - prior_log_odds));
@@ -537,7 +540,7 @@ static long fimo_score_sequence(
 
       // Sequences must be in the same order in the FASTA file and PSP file.
       // So the seq names from the psp reader and seq reader had better match
-      // now
+      // now.
       if (!psp_result || strcmp(fasta_seq_name, psp_seq_name) != 0) {
         die(
           "Sequence name %s from PSP file %s doesn't match\n"
@@ -698,7 +701,7 @@ static long fimo_score_sequence(
     }
   }
 
-  // Count reminaing positions in the sequence.
+  // Count remaining positions in the sequence.
   num_positions += get_num_read_into_data_block(seq_block);
 
   free_data_block(seq_block);
