@@ -29,6 +29,8 @@ typedef struct {
 typedef struct {
   args a;
   FILE *out;
+  char *txt_filename;
+  char *html_filename;
   alphabet alph;
   motif m;
   glam2_scorer scorer;
