@@ -5,7 +5,9 @@
 #include <stdio.h>
 
 typedef struct {
-  const char *out_file;
+  char *out_dir;
+  int clobber;          /* allow files to be clobbered */
+  bool text_only;
   int hit_num;  /* number of alignments to report */
   int two_strands;
   double delete_pseudo;
@@ -16,6 +18,7 @@ typedef struct {
   const char *alph_name;  /* "n" = nucleotide, "p" = protein */
   const char *motif_file;
   const char *seq_file;
+  int quiet;
 } args;
 
 void printargs(FILE *fp, int argc, char **argv);
