@@ -203,13 +203,13 @@ inline void save_legal_sequence(
   Seqptr sptr,			// sequence pointer record to save
   Uint alen,			// alphabet length
   Uchar *compalph,		// lookup table of letter complements
-  BOOL use_rc,			// ensure results are independent of strand
+  BOOL use_smaller_strand,	// ensure results are independent of strand
   BOOL is_rna,			// motifs are RNA, sequences may be DNA so convert
   Uint minlength		// minimum allowed sequence length
 ) {
   if (sptr.seqlen >= minlength) {
     if (is_rna) convert_dna_to_rna(sptr);
-    if (use_rc) convert_to_rc_if_smaller(sptr, alen, compalph);
+    if (use_smaller_strand) convert_to_rc_if_smaller(sptr, alen, compalph);
     PUSHARRAY(seqptrs, Seqptr, 4096, sptr); 
   } else {
     DEBUG_FMT(QUIET_VERBOSE, "# Warning: Ignoring sequence '>%*.*s' because it is too short (%d < %d).\n",
@@ -227,9 +227,10 @@ inline void save_legal_sequence(
 Sint read_fasta_to_multiseqs(
   Multiseq **train_multiseq_ptr,// the training sequences	// OUT
   Multiseq **test_multiseq_ptr,	// the test sequences		// OUT
-  double hofract,		// put this fraction of sequences in test_multiseq
+  double hofract,		// put this fraction of sequences in test_multiseq; put none if < 0
   int min_ho_size,		// minimum allowed number of test sequences
-  BOOL use_rc,			// ensure results are independent of strand
+  BOOL use_rc,			// average complementary letter frequencies
+  BOOL use_smaller_strand,	// ensure results are independent of strand
   BOOL is_rna,			// motifs are RNA, sequences may be DNA so convert
   BOOL allow_ambigs,		// don't convert ambiguous characters to SEPARATOR
   char *filename,		// the FASTA file name to read from
@@ -284,7 +285,7 @@ Sint read_fasta_to_multiseqs(
       if (*inputptr == FASTASEPARATOR) {
 	// Save the previous sequence record on the stack and start the new one.
 	if (num_sequences_read > 0) {
-          save_legal_sequence(&seqptrs, sptr, alen, compalph, use_rc, is_rna, minlength);
+          save_legal_sequence(&seqptrs, sptr, alen, compalph, use_smaller_strand, is_rna, minlength);
         }
         num_sequences_read++;
 	sptr.id = inputptr+1;		// Don't include the ">" in the ID.
@@ -317,7 +318,7 @@ Sint read_fasta_to_multiseqs(
 
   // Push the last sequence onto the sequence pointer array.
   if (num_sequences_read > 0) {
-    save_legal_sequence(&seqptrs, sptr, alen, compalph, use_rc, is_rna, minlength);
+    save_legal_sequence(&seqptrs, sptr, alen, compalph, use_smaller_strand, is_rna, minlength);
   }
 
   // Check that there were sequences read.
@@ -342,7 +343,7 @@ Sint read_fasta_to_multiseqs(
   // Determine the length of the training and test multiseq arrays.
   Uint train_len = 0;	// total length of training sequences
   Uint test_len = 0;	// total length of length sequences
-  int ntest = (hofract * nseqs);
+  int ntest = MAX(0, (hofract * nseqs));		// 0 if hofract <= 0
   if (hofract > 0 && ntest < min_ho_size) ntest = 0;	// prevent too small test set
   int ntrain = nseqs - ntest;
 
