@@ -593,7 +593,7 @@ static int next_token(JSONRD_T *jsonrd, const char *chunk, size_t size) {
     }
   }
   // in progress
-  assert(jsonrd->token.state = TS_IN_PROGRESS);
+  assert((jsonrd->token.state = TS_IN_PROGRESS));
   switch (jsonrd->token.type) {
     case TOK_true:
       return process_keyword_token(jsonrd, chunk, size, i, "true", 4);
