@@ -10,6 +10,7 @@
 #include "matrix.h"
 #include "array.h"
 #include "utils.h"
+#include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -25,16 +26,11 @@ MATRIX_T* allocate_matrix
   MATRIX_T* new_matrix;
   int i;
 
-  if ((new_matrix = (MATRIX_T *)mm_malloc(sizeof(MATRIX_T))) == NULL) {
-    die("Error allocating matrix.\n");
-  }
-
-  if ((new_matrix->rows = (ARRAY_T**)mm_malloc(sizeof(ARRAY_T*) * num_rows))
-      == NULL) {
-    die("Error allocating matrix rows.\n");
-  }
+  new_matrix = (MATRIX_T *)mm_malloc(sizeof(MATRIX_T));
+  new_matrix->rows = (ARRAY_T**)mm_malloc(sizeof(ARRAY_T*) * num_rows);
   for (i = 0; i < num_rows; i++) {
     new_matrix->rows[i] = allocate_array(num_cols);
+    assert(get_array_length(new_matrix->rows[i]) == num_cols);
   }
 
   /* Store the number of rows and columns. */
@@ -133,7 +129,7 @@ void remove_matrix_row
   // Copy all the other rows.
   num_rows = get_num_rows(matrix);
   for (i_row = row_index + 1; i_row < num_rows; i_row++) {
-    // FIXME: CEG Do we really need to copy the arrays?
+    // TODO: CEG Do we really need to copy the arrays?
     // Can't we just move the row pointers?
     copy_array(matrix->rows[i_row], matrix->rows[i_row-1]);
   }
@@ -157,7 +153,7 @@ void remove_matrix_row
  * Remove one column from a matrix.
  **************************************************************************/
 void remove_matrix_col
-  (int        row_index,
+  (int        col_index,
    MATRIX_T*  matrix)
 {
   int i_row;
@@ -165,12 +161,58 @@ void remove_matrix_col
 
   num_rows = get_num_rows(matrix);
   for (i_row = 0; i_row < num_rows; i_row++) {
-    remove_array_item(row_index, get_matrix_row(i_row, matrix));
+    remove_array_item(col_index, get_matrix_row(i_row, matrix));
   }
 
   (matrix->num_cols)--;
 }
 
+/**************************************************************************
+ * Resize the matrix filling in all new positions with the passed
+ * value.
+ **************************************************************************/
+void resize_matrix
+  (int row_count, int col_count, MTYPE value, MATRIX_T *matrix)
+{
+  int orig_rows, orig_cols, i_row, i_col, row_min;
+
+  orig_rows = get_num_rows(matrix);
+  orig_cols = get_num_cols(matrix);
+
+  // nothing to do
+  if (orig_rows == row_count && orig_cols == col_count) return;
+
+  if (orig_cols != col_count) {
+    row_min = (orig_rows < row_count ? orig_rows : row_count);
+    // resize existing columns
+    for (i_row = 0; i_row < row_min; ++i_row) {
+      resize_array(matrix->rows[i_row], col_count);
+      // fill in the new columns in the existing rows with the passed default
+      for (i_col = orig_cols; i_col < col_count; ++i_col) {
+        set_array_item(i_col, value, matrix->rows[i_row]);
+      }
+    }
+  }
+  if (orig_rows != row_count) {
+    if (row_count > orig_rows) {
+      // add the new rows
+      matrix->rows = mm_realloc(matrix->rows, sizeof(ARRAY_T*) * row_count);
+      // fill in the new rows with the passed default
+      for (i_row = orig_rows; i_row < row_count; ++i_row) {
+        matrix->rows[i_row] = allocate_array(col_count);
+        init_array(value, matrix->rows[i_row]);
+      }
+    } else {
+      for (i_row = row_count; i_row < orig_rows; ++i_row) {
+        free_array(matrix->rows[i_row]);
+        matrix->rows[i_row] = NULL;
+      }
+      matrix->rows = mm_realloc(matrix->rows, sizeof(ARRAY_T*) * row_count);
+    }
+  }
+  matrix->num_rows = row_count;
+  matrix->num_cols = col_count;
+}
 
 
 /**************************************************************************
@@ -204,7 +246,7 @@ static void matrix_row_check
     die("Invalid matrix row (%d).\n", row);
   } else if (row > get_num_rows(matrix)) {
     die("Matrix row out of bounds (%d > %d).\n",
-  row > get_num_rows(matrix));
+        row, get_num_rows(matrix));
   }
 #else
   /* Avoid compiler warning. */
@@ -314,6 +356,31 @@ ARRAY_T* get_matrix_column
   return(column);
 }
 
+/***********************************************************************
+ * Get a copy of a column from a matrix.
+ *
+ * Copies the column into the passed array resizing the array if needed.
+ ***********************************************************************/
+ARRAY_T* get_matrix_column2
+  (int       i_col,
+   ARRAY_T* buffer,
+   MATRIX_T* matrix)
+{
+  int i_row;
+  int num_rows;
+
+  /* Allocate space for the copy of the column. */
+  num_rows = get_num_rows(matrix);
+  if (get_array_length(buffer) != num_rows) resize_array(buffer, num_rows);
+
+  /* Copy elements of the column into an array. */
+  for (i_row = 0; i_row < num_rows; i_row++) {
+    set_array_item(i_row, get_matrix_cell(i_row, i_col, matrix), buffer);
+  }
+
+  return buffer;
+}
+
 /***********************************************************************
  * Set a column in a matrix.
  ***********************************************************************/
@@ -333,12 +400,11 @@ void set_matrix_column
 }
 
 
-
 /***********************************************************************
  * Turn an array into a matrix.
  ***********************************************************************/
 MATRIX_T* array_to_matrix
-  (BOOLEAN_T one_row, /* Put the array in one row, or in many. */
+  (bool one_row, /* Put the array in one row, or in many. */
    ARRAY_T*  array)
 {
   MATRIX_T* new_matrix;
@@ -378,7 +444,7 @@ void copy_matrix
     die("Attempted to copy matrices with different numbers of rows (%d != %d)\n",
       num_rows, get_num_rows(target_matrix));
   }
-  myassert(TRUE, get_num_cols(source_matrix) == get_num_cols(target_matrix),
+  myassert(true, get_num_cols(source_matrix) == get_num_cols(target_matrix),
      "Copying matrix with %d columns into matrix with %d columns.\n",
      get_num_cols(source_matrix), get_num_cols(target_matrix));
 
@@ -487,8 +553,8 @@ ARRAY_T* extract_diagonal
 /**************************************************************************
  * Determine whether a given matrix is symmetric.
  **************************************************************************/
-BOOLEAN_T is_symmetric
-  (BOOLEAN_T verbose,
+bool is_symmetric
+  (bool verbose,
    MTYPE     slop,
    MATRIX_T* matrix)
 {
@@ -514,11 +580,11 @@ BOOLEAN_T is_symmetric
     fprintf(stderr, "matrix[%d][%d]=%g matrix[%d][%d]=%g diff=%g\n",
       i_row, i_col, upper, i_col, i_row, lower, upper - lower);
   }
-  return(FALSE);
+  return(false);
       }
     }
   }
-  return(TRUE);
+  return(true);
 }
 
 /**************************************************************************
@@ -585,7 +651,7 @@ void add_to_diagonal
 /***********************************************************************
  * Determine whether two matrices are equal, within a given bound.
  ***********************************************************************/
-BOOLEAN_T equal_matrices
+bool equal_matrices
   (ATYPE    close_enough,
    MATRIX_T* matrix1,
    MATRIX_T* matrix2)
@@ -605,10 +671,10 @@ BOOLEAN_T equal_matrices
     if (!equal_arrays(close_enough, get_matrix_row(i_row, matrix1),
           get_matrix_row(i_row, matrix2))) {
       fprintf(stderr, "Matrices differ in row %d.\n", i_row);
-      return(FALSE);
+      return(false);
     }
   }
-  return(TRUE);
+  return(true);
 }
 
 /**************************************************************************
@@ -666,7 +732,7 @@ void mult_matrix
  * Convert a given matrix to or from logs.
  **************************************************************************/
 void convert_to_from_log_matrix
-  (BOOLEAN_T  to_log,
+  (bool  to_log,
    MATRIX_T*  source_matrix,
    MATRIX_T*  target_matrix)
 {
@@ -835,7 +901,7 @@ void print_matrix
   (MATRIX_T* matrix,        /* The matrix to be printed. */
    int       width,         /* Width of each cell. */
    int       precision,     /* Precision of each cell. */
-   BOOLEAN_T print_titles,  /* Include row and column indices? */
+   bool print_titles,  /* Include row and column indices? */
    FILE*     outfile)       /* File to which to write. */
 {
   int num_rows = get_num_rows(matrix);
@@ -864,7 +930,7 @@ void print_matrix
       fprintf(outfile, "%2d ", i_row);
     }
     column = get_matrix_column(i_row, matrix);
-    print_array(column, width, precision, TRUE, outfile);
+    print_array(column, width, precision, true, outfile);
     free_array(column);
   }
 }
@@ -1041,7 +1107,7 @@ void normalize_matrix
   int       num_cols;
   int       i_row;
   int       i_col;
-  BOOLEAN_T keep_going; /* Are we tolerably close to a normalized matrix? */
+  bool keep_going; /* Are we tolerably close to a normalized matrix? */
   MTYPE     total;
 
   /* Get the matrix dimensions. */
@@ -1057,7 +1123,7 @@ void normalize_matrix
   one_column = allocate_array(num_rows);
 
   /* Iterate until we're told to stop. */
-  keep_going = TRUE;
+  keep_going = true;
   for (iter = 0; keep_going; iter++) {
 
     /* First normalize the rows. */
@@ -1086,7 +1152,7 @@ void normalize_matrix
     }
 
     /* Now find out whether all rows are close enough to 1.0. */
-    keep_going = FALSE;
+    keep_going = false;
     for (i_row = 0; i_row < num_rows; i_row++) {
       total = array_total(get_matrix_row(i_row, matrix));
       if (!almost_equal(1.0, total, tolerance)) {
@@ -1096,7 +1162,7 @@ void normalize_matrix
     fprintf(stderr, "Iteration %d: row %d has difference of %g\n",
       iter, i_row, 1.0 - total);
   }
-  keep_going = TRUE;
+  keep_going = true;
   break;
       }
 
@@ -1198,7 +1264,7 @@ int reverse_array_compare
 }
 
 void sort_matrix_rows
-  (BOOLEAN_T reverse_sort,
+  (bool reverse_sort,
    ARRAY_T*  keys,
    MATRIX_T* matrix)
 {
@@ -1255,7 +1321,7 @@ void shuffle_matrix
       for (i_col = 0; i_col < num_cols; i_col++)
   {
     /* Call pseudo random number generator only once per entry. */
-    entry = my_drand() * num_entries;
+    entry = drand_mt() * num_entries;
     i_row_rand = entry / num_cols;
     i_col_rand = entry % num_cols;
 
@@ -1270,10 +1336,69 @@ void shuffle_matrix
 }
 
 /*****************************************************************************
- * Randomly shuffle the rows or columns of a matrix. If the boolean cols is TRUE * shuffle the columns else shuffle the rows
+ * Swap two rows in the matrix.
+ *****************************************************************************/
+static inline void swap_rows(MATRIX_T *matrix, int row1, int row2) {
+  MTYPE temp;
+  int i;
+  if (row1 == row2) return;
+  for (i = 0; i < matrix->num_cols; i++) {
+    // swap matrix cells
+    temp = get_matrix_cell(row1, i, matrix);
+    set_matrix_cell(row1, i, get_matrix_cell(row2, i, matrix), matrix);
+    set_matrix_cell(row2, i, temp, matrix);
+  }
+}
+
+/*****************************************************************************
+ * Swap two columns in the matrix.
+ *****************************************************************************/
+static inline void swap_columns(MATRIX_T *matrix, int col1, int col2) {
+  MTYPE temp;
+  int i;
+  if (col1 == col2) return;
+  for (i = 0; i < matrix->num_rows; i++) {
+    // swap matrix cells
+    temp = get_matrix_cell(i, col1, matrix);
+    set_matrix_cell(i, col1, get_matrix_cell(i, col2, matrix), matrix);
+    set_matrix_cell(i, col2, temp, matrix);
+  }
+}
+
+/*****************************************************************************
+ * Rearrange the first count rows or columns to the ordering specified by
+ * permutation.
+ *
+ * Note that permutation is used temporarily to record which columns are in
+ * their correct position so it must be writeable.
+ *
+ *****************************************************************************/
+void permute_matrix(MATRIX_T *matrix, bool cols, int *permutation, int count) {
+  int i, pos;
+  for (i = 0; i < count; i++) {
+    // skip columns already in position
+    while (i < count && permutation[i] < 0) i++;
+    pos = i;
+    // swap columns in a chain
+    while (permutation[pos] != i) {
+      if (cols) swap_columns(matrix, pos, permutation[pos]);
+      else swap_rows(matrix, pos, permutation[pos]);
+      pos = permutation[pos];
+      permutation[pos] = -(permutation[pos] + 1); // mark column as correctly positioned
+    }
+  }
+  // undo the marking of the columns so permutation can be used again
+  for (i = 0; i < count; i++) {
+    if (permutation[i] < 0) permutation[i] = -(permutation[i] + 1);
+  }
+}
+
+/*****************************************************************************
+ * Randomly shuffle the rows or columns of a matrix. If the boolean cols is true
+ * shuffle the columns else shuffle the rows
  *****************************************************************************/
 void shuffle_matrix_cols
-  (MATRIX_T* matrix, BOOLEAN_T cols)
+  (MATRIX_T* matrix, bool cols)
 {
   int   i_row;
   int   i_col;
@@ -1289,7 +1414,7 @@ void shuffle_matrix_cols
   if (cols){
     /* Call pseudo random number generator only once per entry. */
     for (i_col = 0; i_col < num_cols; i_col++){
-      i_col_rand = my_drand() * (num_cols-1);
+      i_col_rand = drand_mt() * (num_cols-1);
       /* Swap the columns */
       ARRAY_T* temp_array = NULL;
       temp_array = get_matrix_column(i_col, matrix);
@@ -1308,7 +1433,7 @@ void shuffle_matrix_cols
   else{
     /* Call pseudo random number generator only once per entry. */
     for (i_row = 0; i_row < num_rows; i_row++){
-      i_row_rand = my_drand() * (num_rows-1);
+      i_row_rand = drand_mt() * (num_rows-1);
       /*       Swap the rows */
       int temp_index;
       for (temp_index = 0; temp_index < num_cols; temp_index++){
