@@ -170,6 +170,18 @@ int compare_mcast_match_pvalues(const void *param1, const void *param2) {
   else if (match1->pvalue < match2->pvalue) {
     return -1;
   }
+  else if (match1->score < match2->score) {
+    return 1;
+  }
+  else if (match1->score > match2->score) {
+    return -1;
+  }
+  else if (match1->gc < match2->gc) {
+    return 1;
+  }
+  else if (match1->gc > match2->gc) {
+    return -1;
+  } 
   else {
     return 0;
   }
@@ -985,7 +997,6 @@ void mcast_print_results_as_html(
   long max_stored_scores,
   double motif_pthresh,
   double alpha,
-  bool synth,
   uint32_t seed,
   bool genome_coords,
   bool stats_available,
@@ -1055,7 +1066,6 @@ void mcast_print_results_as_html(
   jsonwr_dbl_prop(json, "gap_extend_cost", options->gap_extend);
   jsonwr_bool_prop(json, "hard_mask", options->hard_mask);
   jsonwr_bool_prop(json, "norc", norc);
-  jsonwr_bool_prop(json, "synth", synth);
   jsonwr_bool_prop(json, "genomic_coord", genome_coords);
   jsonwr_bool_prop(json, "stats", stats_available);
   jsonwr_lng_prop(json, "seed", seed);
