@@ -10,6 +10,7 @@
 #include <time.h>
 #include "utils.h"
 #include "metameme.h"
+#include "citation.js.h"
 
 /*************************************************************************
  * Print the program header, including help info, if necessary.
@@ -50,6 +51,8 @@ void write_header
   fprintf(outfile, "# To get a copy of the MEME Suite software, ");
   fprintf(outfile, "please access %s.\n", SOURCE_URL);
   fprintf(outfile, "# \n");
+  fprintf(outfile, MCAST_CITE);
+#ifdef BAD
   fprintf(outfile, "# If you use MCAST in your research, please cite\n");
   fprintf(outfile, "# \n");
   fprintf(
@@ -60,6 +63,7 @@ void write_header
     "Computational Biology),\n"
     "#  19(Suppl. 2):ii16-ii25, 2003.\n"
   );
+#endif
   fprintf(outfile, "# \n");
   fprintf(
     outfile, 
@@ -67,5 +71,3 @@ void write_header
     "***********************************\n"
   );
 }
-
-
