@@ -6,6 +6,11 @@
  * COPYRIGHT: 2001-2008, WSN
  * DESCRIPTION: Given Meta-MEME model, randomly emit sequences.
  ********************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include "utils.h"
 #include "mhmm-state.h"
 #include "read-mhmm.h"
@@ -103,9 +108,6 @@ static void emit_sequence
   fprintf(outfile, "\n");
 }
 
-
-VERBOSE_T verbosity = INVALID_VERBOSE;
-
 /*************************************************************************
  * int main
  *************************************************************************/
@@ -145,7 +147,7 @@ int main(int argc, char *argv[])
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -153,7 +155,7 @@ int main(int argc, char *argv[])
       break;
     } else if (c < 0) {
       simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     // Get the option name (we only use long options).
