@@ -4,9 +4,14 @@
  * CREATE DATE: 8-13-97
  * PROJECT: MHMM
  * VERSION: $Revision: 1.3 $
- * COPYRIGHT: 1998-2002, WNG, 2001-2002, TLB
+ * COPYRIGHT: 1998-2002, WNG, 2001-2023, TLB
  * DESCRIPTION: Search a database of sequences using a motif-based HMM.
  **************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -1177,57 +1182,6 @@ void sort_and_print_scores
   myfree(stored_gcs);
 }
 
-/***********************************************
- * Calculate the score distribution.
- ***********************************************/
-EVD_SET calc_distr(
-  SCORE_SET score_set,	  // Set of scores and lengths.
-  DISTR_T dtype,          // Type of score distribution
-  bool match_evalues	// Use match E-values?
-)
-{
-  double H = 0;				// don't use H 
-  int maxiter1 = 10;			// max. iterations in L-H loop
-  int maxiter2 = 20;			// max. iterations in N-R loop
-  int size = 1000;			// size of length groups 
-  int min_scores = 0;
-  double lspan = 1.5;			// min. length ratio/group 
-
-  switch(dtype) {
-    case D_EVD:
-      lspan = 1.5;
-      min_scores = 200;
-      break;
-    case D_EXP:
-      lspan = 1.025;
-      min_scores = 200;
-      break;
-    case D_GCEXP:
-      lspan = 101;
-      //min_scores = 0;
-      min_scores = 2;		// old value could cause log(-1) in fit_score_distribution().
-      break;
-    default:
-      die("Unknown distribution type.");
-      break;
-  }
-
-  //
-  // If using match E-values instead of score E-values, set all
-  // the sequence lengths to total_length/# matches.
-  //
-  if (dtype==D_EVD && match_evalues) {
-    int i;
-    int length = score_set.n ? score_set.total_length/score_set.n : score_set.total_length;
-    for (i=0; i<score_set.n; i++) score_set.scores[i].t = length;
-    score_set.max_t = length;
-  }
-
-  // Fit the distribution to the scores and lengths.
-  return(fit_score_distribution(dtype, score_set, H, maxiter1, maxiter2, EPS1, EPS2, size, min_scores, lspan));
-
-} // calc_distr 
-
 /*************************************************************************
 * Calculate the E-values of sequence scores and store them as the keys.
 *************************************************************************/
@@ -1272,8 +1226,6 @@ void calc_evalues (
 #ifdef MAIN
 #include "simple-getopt.h"
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 /**************************************************************************
  * int main
  **************************************************************************/
@@ -1446,7 +1398,7 @@ int main (int argc, char *argv[])
         break;
       } else if (c < 0) {
         simple_getopterror(&message);
-        die("Error process command line options (%s)\n", message);
+        die("Error process command line options: %s\n", message);
       }
 
       if (strcmp(option_name, "paths") == 0) {
@@ -1474,7 +1426,7 @@ int main (int argc, char *argv[])
       } else if (strcmp(option_name, "progress") == 0) {
         progress_every = atoi(option_value);
       } else if (strcmp(option_name, "verbosity") == 0) {
-        verbosity = (VERBOSE_T)atoi(option_value);
+        verbosity = atoi(option_value);
       } else if (strcmp(option_name, "noheader") == 0) {
         print_header = false;
       } else if (strcmp(option_name, "noparams") == 0) {
