@@ -6,7 +6,10 @@
  * COPYRIGHT: 2004, UW
  ********************************************************************/
 
+#ifdef MAIN
 #define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
@@ -26,9 +29,9 @@
 #include "simple-getopt.h"
 #include "tree.h"
 #include "object-list.h"
+#include "utils.h"
 
 char* program_name = NULL;
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 
 /*******************************************************************
   Print the column frequency distribution.
@@ -194,7 +197,7 @@ int main(int argc, char *argv[]) {
     int c = 0;
     char* option_name = NULL;
     char* option_value = NULL;
-    const char * message = NULL;
+    const char* message = NULL;
 
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
@@ -202,7 +205,7 @@ int main(int argc, char *argv[]) {
       break;
     } else if (c < 0) {
       (void) simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "bg") == 0){
