@@ -6,6 +6,11 @@
  * COPYRIGHT: 2007, UW
  * DESCRIPTION: q value calculation, a la Benjamini Hochberg
  *************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include "utils.h"
 #include "qvalue.h"
 #include "array.h"
@@ -111,10 +116,7 @@ ARRAY_T* read_scores_from_column
   }
   fclose(score_file);
   int num_scores = i_score;
-  if (verbosity >= NORMAL_VERBOSE) {
-    fprintf(stderr, "Read %d values from %s.\n", num_scores,
-	    score_filename);
-  }
+  DEBUG_FMT(NORMAL_VERBOSE, "# Read %d values from %s.\n", num_scores, score_filename);
 
   // Make a smaller array to contain just the scores.
   ARRAY_T* scores = allocate_array(num_scores);
@@ -209,9 +211,7 @@ double estimate_pi_zero
    float    max_lambda,            // Maximum lambda value to consider.
    ARRAY_T* p_values)
 {
-  if (verbosity >= NORMAL_VERBOSE) {
-    fprintf(stderr, "  Estimating pi_0.\n");
-  }
+  DEBUG_MSG(NORMAL_VERBOSE, "#   Estimating pi_0.\n");
   
   int num_pvalues = get_array_length(p_values);
 
@@ -234,19 +234,14 @@ double estimate_pi_zero
 
   // Find the minimal pi_zero.
   double min_pi_zero = get_array_minimum(pi_zeroes);
-  if (verbosity > NORMAL_VERBOSE) {
-    fprintf(stderr, "Minimal pi_zero = %g\n", min_pi_zero);
-  }
+  DEBUG_FMT(NORMAL_VERBOSE, "# Minimal pi_zero = %g\n", min_pi_zero);
 
   // Choose the lambda which minimizes the mean-squared error of our estimates.
-  if (verbosity >= DUMP_VERBOSE) {
-    fprintf(stderr, "Performing %d bootstraps.\n", num_bootstraps);
-  }
+  DEBUG_FMT(DUMP_VERBOSE, "# Performing %d bootstraps.\n", num_bootstraps);
+
   int i_bootstrap;
   for (i_bootstrap = 0; i_bootstrap < num_bootstraps; i_bootstrap++) {
-    if (verbosity >= DUMP_VERBOSE) {
-      fprintf(stderr, "Bootstrap %d\n", i_bootstrap);
-    }
+    DEBUG_FMT(DUMP_VERBOSE, "#   Bootstrap %d\n", i_bootstrap);
 
     // Create an array of bootstrapped p-values.
     ARRAY_T* bootstrapped_pvalues = bootstrap_array(p_values,
@@ -280,10 +275,8 @@ double estimate_pi_zero
       minimal_error = this_error;
     }
   }
-  if (verbosity >= DUMP_VERBOSE) {
-    fprintf(stderr, "Minimal error = %g\n", minimal_error);
-    fprintf(stderr, "Index of best lambda = %d\n", best_lambda_index);
-  }
+  DEBUG_FMT(DUMP_VERBOSE, "# Minimal error = %g\n", minimal_error);
+  DEBUG_FMT(DUMP_VERBOSE, "# Index of best lambda = %d\n", best_lambda_index);
 
   // Use the corresponding pi_zero.
   double pi_zero = get_array_item(best_lambda_index, pi_zeroes);
@@ -291,9 +284,7 @@ double estimate_pi_zero
   // Ensure the pi_zero estimate is in the right range.
   pi_zero = MAX(MIN(pi_zero, 1.0), 0.0);
 
-  if (verbosity >= NORMAL_VERBOSE) {
-    fprintf(stderr, "  Estimated pi_0=%g\n", pi_zero);
-  }
+  DEBUG_FMT(NORMAL_VERBOSE, "#   Estimated pi_0=%g\n", pi_zero);
 
   // If requested, store the estimated pi-zero as a function of lambda.
   if (pi_zero_filename != NULL) {
@@ -345,6 +336,8 @@ void compute_qvalues(
   ARRAY_T*  sampled_pvalues  // uniformly sampled pvalues
 ) {
 
+  DEBUG_MSG(NORMAL_VERBOSE, "# Computing q-values.\n");
+
   // Make sure we got at least one p-value.
   int num_values = get_array_length(pvalues);
   if (num_values == 0) {
@@ -372,13 +365,7 @@ void compute_qvalues(
     if (have_all_pvalues) {
       if (num_values > (long) MIN_SAMPLES) {
         // Estimate pi0 from complete set of pvalues
-        if (verbosity >= NORMAL_VERBOSE) {
-          fprintf(
-            stderr, 
-            "  Estimating pi_0 from all %d observed p-values.\n",
-            num_values
-          );
-        }
+        DEBUG_FMT(NORMAL_VERBOSE, "#   Estimating pi_0 from all %d observed p-values.\n", num_values);
         pi_zero = estimate_pi_zero(
            pi_zero_filename,
            num_bootstraps,
@@ -388,28 +375,16 @@ void compute_qvalues(
            pvalues
         );
       } else {
-        if (verbosity >= NORMAL_VERBOSE) {
-          fprintf(
-            stderr, 
-            "Warning: Cannot estimate pi_0 accurately from fewer than %d p-values."
-            "         total p-values = %d. Using pi_zero = 1.0.\n",
-            MIN_SAMPLES,
-            num_values
-          );
-        }
+        DEBUG_FMT(NORMAL_VERBOSE,
+            "#   Cannot estimate pi_0 accurately from fewer than %d p-values.\n"
+            "#   Total p-values = %d. Using pi_zero = 1.0.\n", MIN_SAMPLES, num_values
+        );
       }
     } else if (sampled_pvalues != NULL) {
       int num_samples = get_array_length(sampled_pvalues);
       if (num_samples > MIN_SAMPLES) {
         // Estimate pi0 from uniformly sampled pvalues
-        if (verbosity >= NORMAL_VERBOSE) {
-          fprintf(
-            stderr,
-            "  Estimating pi_0 from a uniformly sampled set "
-            "of %d p-values.\n",
-            num_samples
-          );
-        }
+        DEBUG_FMT(NORMAL_VERBOSE, "#   Estimating pi_0 from a uniformly sampled set of %d p-values.\n", num_samples);
         pi_zero = estimate_pi_zero(
            pi_zero_filename,
            num_bootstraps,
@@ -418,22 +393,19 @@ void compute_qvalues(
            max_lambda,
            sampled_pvalues
         );
-      } 
-      else {
-        fprintf(
-          stderr, 
-          "Warning: Cannot estimate pi_0 accurately from fewer "
-          "than %d sampled p-values.\n"
-          "         only %d p-values were sampled. Using pi_zero = 1.0.\n",
+      } else {
+        DEBUG_FMT(QUIET_VERBOSE,
+          "# Warning: Cannot estimate pi_0 accurately from fewer\n"
+          "#          than %d sampled p-values.\n"
+          "#          Only %d p-values were sampled. Using pi_zero = 1.0.\n",
           MIN_SAMPLES,
           num_samples
         );
       }
     } else {
-      fprintf(
-        stderr, 
-        "Warning: Cannot estimate pi_zero without the complete range of p-values,\n"
-        "         or a uniformly sampled subset of pvalues. Using pi_zero = 1.0.\n"
+      DEBUG_MSG(QUIET_VERBOSE,
+	"# Warning: Cannot estimate pi_zero without the complete range of p-values,\n"
+	"#        or a uniformly sampled subset of pvalues. Using pi_zero = 1.0.\n"
       );
     }
   }
@@ -481,9 +453,7 @@ void convert_scores_to_pvalues
    ARRAY_T*  observed_scores,
    ARRAY_T*  null_scores)
 {
-  if (verbosity >= NORMAL_VERBOSE) {
-    fprintf(stderr, "Converting scores to p-values.\n");
-  }
+  DEBUG_MSG(NORMAL_VERBOSE, "Converting scores to p-values.\n");
 
   // Sort both arrays in order, best to worst.
   sort_array(good_score_is_low != true, observed_scores);
@@ -522,7 +492,6 @@ void convert_scores_to_pvalues
 #ifdef MAIN
 
 #include "simple-getopt.h"
-VERBOSE_T verbosity = INVALID_VERBOSE;
 
 int main
   (int    argc,
@@ -540,7 +509,6 @@ int main
   int       pvalue_column = 0; // Indexed from 0.
   bool append_output = false; // Append q-values to end of input line?
   long      seed = time(0);
-  verbosity = NORMAL_VERBOSE;
 
   const int num_options = 11;
   cmdoption const options[] = {
@@ -579,7 +547,7 @@ int main
   int option_index = 0;
   char* option_name = NULL;
   char* option_value = NULL;
-  const char *  message = NULL;
+  const char* message = NULL;
   simple_setopt(argc, argv, num_options, options);
   while(1) {
     // Read the next option, and break if we're done.
@@ -588,7 +556,7 @@ int main
       break;
     } else if (c < 0) {
       simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "null") == 0) {
