@@ -14,6 +14,10 @@
  *
  ********************************************************************/
 
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -110,13 +114,10 @@ typedef struct {
   double f_score;
 } ramen_rank_t;
 
-
-
 /*
  * Global Variables
  */
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 ramen_arg_t args;
 ramen_arg_t default_args;
 
@@ -274,7 +275,7 @@ void ramen_getopt(int argc, char *argv[]) {
   int option_index = 0;
   char* option_name = NULL;
   char* option_value = NULL;
-  const char * message = NULL;
+  const char* message = NULL;
   bool bad_options = false;
   int i;
 
@@ -355,7 +356,7 @@ void ramen_getopt(int argc, char *argv[]) {
       printf("%s",ramen_get_usage()); //not to stderr
       ramen_terminate(0);
     } else {
-      printf("Error: %s is not a recognised switch.\n", option_name);
+      printf("Error: %s is not a recognized switch.\n", option_name);
       ramen_usage();
       ramen_terminate(1);
     }
