@@ -7,7 +7,6 @@
  * DESCRIPTION: Functions for reading HMMs in MHMM format.
  *************************************************************************/
 #include <assert.h>
-#include <err.h>
 #include <errno.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
@@ -29,12 +28,13 @@
  *************************************************************************/
 #define BUF_LENGTH 100
 static void read_mhmm_state(
+   ALPH_T* alph,
    FILE * const   model_file,
    const int      i_state, 
    MHMM_STATE_T * this_state
 ) {
   int state_num;    /* State index read from file. */
-  int alph_size;    /* Number of characters in the alphabet. */
+  int asize;    /* Number of characters in the alphabet. */
   int i_alph;       /* Index of the current letter. */
   int num_scan;     /* Number of items scanned by fscanf(). */
   char buffer[BUF_LENGTH]; /* Buffer for reading strings from the file. */
@@ -66,14 +66,16 @@ static void read_mhmm_state(
   assert(num_scan == 1);
 
   /* Allocate space for the emission distributions. */
-  this_state->emit = allocate_array(get_alph_size(ALL_SIZE));
-  this_state->emit_odds = allocate_array(get_alph_size(ALL_SIZE));
+  this_state->emit = allocate_array(alph_size_full(alph));
+  this_state->emit_odds = allocate_array(alph_size_full(alph));
 
   /* Read emission distribution from non-start-or-end states. */
-  alph_size = get_alph_size(ALPH_SIZE);
+  asize = alph_size_core(alph);
   if ((this_state->type != START_STATE) && (this_state->type != END_STATE)) {
-    fscanf(model_file, " emit: ");
-    for (i_alph = 0; i_alph < alph_size; i_alph++) {
+    if (fscanf(model_file, " %5[emit]: ", buffer) != 1 || strcmp(buffer, "emit") != 0) {
+      die("Missing \" emit: \"\n");
+    }
+    for (i_alph = 0; i_alph < asize; i_alph++) {
       num_scan = fscanf(model_file, PROB_SCAN, &this_emit);
       set_array_item(i_alph, this_emit, this_state->emit);
       assert(num_scan == 1);
@@ -83,12 +85,12 @@ static void read_mhmm_state(
     normalize(0.00001, this_state->emit);
 
     /* Calculate probabilities for ambiguous characters. */
-    fill_in_ambiguous_chars(FALSE, this_state->emit);
+    calc_ambigs(alph, false, this_state->emit);
   }
 
   /* Assign 1.0 probabilities to start and end emissions. */
   else {
-    for (i_alph = 0; i_alph < get_alph_size(ALL_SIZE); i_alph++) {
+    for (i_alph = 0; i_alph < alph_size_full(alph); i_alph++) {
       set_array_item(i_alph, 1.0, this_state->emit);
     }
   }
@@ -103,6 +105,7 @@ static void read_mhmm_trans(
   const int num_states,
   MATRIX_T* trans
 ) {
+  char      buffer[11];
   int       num_rows;      /* Number of rows and columns (equal). */
   int       num_cols;
   int       i_row;         /* Row and column indices. */
@@ -111,8 +114,8 @@ static void read_mhmm_trans(
 #ifndef NO_RENORMALIZE
   int       one_col;       /* Index of the column in which 1.0 appears. */
   MTYPE     row_sum;       /* Sum of given row (except for the 1.0 entry). */
-  BOOLEAN_T found_one;     /* Does this column contain an entry of 1.0? */
-  BOOLEAN_T found_nonzero; /* ... or an entry other than 0.0? */
+  bool found_one;     /* Does this column contain an entry of 1.0? */
+  bool found_nonzero; /* ... or an entry other than 0.0? */
 #endif
   MTYPE     matrix_item;
 
@@ -136,15 +139,15 @@ static void read_mhmm_trans(
   for (i_row = 0; i_row < num_states; i_row++) {
 
     /* Find out if there's a 1.0 and something nonzero in this row. */
-    found_one = FALSE;
-    found_nonzero = FALSE;
+    found_one = false;
+    found_nonzero = false;
     one_col = 0; /* To prevent compiler warning. */
     for (i_col = 0; i_col < num_states; i_col++) {
       if (get_matrix_cell(i_row, i_col, trans) == 1.0) {
-        found_one = TRUE;
+        found_one = true;
         one_col = i_col;
       } else if (get_matrix_cell(i_row, i_col, trans) != 0.0) {
-	      found_nonzero = TRUE;
+	      found_nonzero = true;
       }
       if (found_one && found_nonzero) {
 	      break;
@@ -175,8 +178,6 @@ static void read_mhmm_trans(
   }
 #endif
 
-  num_scan = fscanf(model_file, " End of MHMM");
-  assert(num_scan == 0);
 }
 
 
@@ -186,6 +187,7 @@ static void read_mhmm_trans(
  * emission probabilities.
  ***********************************************************************/
 static void read_state_emission_prob_from_xml(
+  ALPH_T* alph,
   xmlXPathContextPtr xpath_ctxt,
   ARRAY_T* emission_probs,
   int state_index // chosen state
@@ -194,7 +196,7 @@ static void read_state_emission_prob_from_xml(
   const int MAX_XPATH_EXPRESSION = 200;
   char xpath_expression[MAX_XPATH_EXPRESSION];
 
-  int alph_size = get_alph_size(ALPH_SIZE);
+  int asize = alph_size_core(alph);
   int i_alph = 0;
 
   // Build the XPATH expression to get emission probabilities for chosen state.
@@ -216,12 +218,12 @@ static void read_state_emission_prob_from_xml(
 
     // If not zero, the number of emission probabilities 
     // should match the alphabet size.
-    assert(num_values == alph_size);
+    assert(num_values == asize);
 
     // XML doesn't enforce any order on the emission probability values,
     // so force reading emission probability values in alphabet order.
     xmlNodePtr currValueNode = NULL;
-    for (i_alph = 0; i_alph < alph_size; i_alph++) {
+    for (i_alph = 0; i_alph < asize; i_alph++) {
       // Build the XPATH expression to get emission probability for 
       // a character in the chosen state.
       snprintf(
@@ -230,7 +232,7 @@ static void read_state_emission_prob_from_xml(
         "/MEME_HMM/states/state[@index='%d']/"
         "emission_probabilities/alphabet_array/value[@letter_id='letter_%c']",
         state_index, 
-        get_alph_char(i_alph)
+        alph_char(alph, i_alph)
       );
       // Decode from node set to numeric value for emission prob.
       xpath_obj = xpath_query(xpath_ctxt, xpath_expression);
@@ -244,11 +246,11 @@ static void read_state_emission_prob_from_xml(
     normalize(0.00001, emission_probs);
 
     /* Calculate probabilities for ambiguous characters. */
-    fill_in_ambiguous_chars(FALSE, emission_probs);
+    calc_ambigs(alph, false, emission_probs);
   }
   else {
     /* Assign 1.0 probabilities to start and end emissions. */
-    for (i_alph = 0; i_alph < get_alph_size(ALL_SIZE); i_alph++) {
+    for (i_alph = 0; i_alph < alph_size_full(alph); i_alph++) {
       set_array_item(i_alph, 1.0, emission_probs);
     }
   }
@@ -304,7 +306,8 @@ static void read_mhmm_trans_from_xml(
 /***********************************************************************
  * Read the states from XML.
  ***********************************************************************/
-void read_mhmm_states_from_xml(
+static void read_mhmm_states_from_xml(
+  ALPH_T* alph,
   xmlXPathContextPtr xpath_ctxt, 
   MHMM_T* the_mhmm
 ) {
@@ -371,12 +374,13 @@ void read_mhmm_states_from_xml(
 
     /* Allocate space for the emission distributions. */
     the_mhmm->states[state_index].emit = 
-      allocate_array(get_alph_size(ALL_SIZE));
+      allocate_array(alph_size_full(alph));
     the_mhmm->states[state_index].emit_odds = 
-      allocate_array(get_alph_size(ALL_SIZE));
+      allocate_array(alph_size_full(alph));
 
     // Read the emission probabilities for the state.
     read_state_emission_prob_from_xml(
+      alph,
       xpath_ctxt, 
       the_mhmm->states[state_index].emit,
       state_index
@@ -405,6 +409,7 @@ void read_mhmm_states_from_xml(
  * OUT: the_hmm
  *************************************************************************/
 static void read_mhmm_from_xml(
+  ALPH_T* alph,
   xmlXPathContextPtr xpath_ctxt, 
   MHMM_T** the_hmm
 ) {
@@ -421,13 +426,7 @@ static void read_mhmm_from_xml(
   xmlFree(property);
 
   // Allocate the HMM.
-  allocate_mhmm(num_states, the_hmm);
-  (*the_hmm)->num_states = num_states;
-  strncpy(
-    (*the_hmm)->alphabet, 
-    get_alphabet(FALSE /* don't include ambigs */), 
-    (*the_hmm)->alph_size
-  );
+  *the_hmm = allocate_mhmm(alph, num_states);
 
   // Fill in the number and length of spacers since we already
   // have the states node in hand.
@@ -446,11 +445,6 @@ static void read_mhmm_from_xml(
   xmlFree(property);
   xmlXPathFreeObject(xpath_obj);
 
-  // Set the alphabet information
-  (*the_hmm)->alph_size = get_alph_size(ALPH_SIZE /* Don't include ambigs */);
-  strcpy((*the_hmm)->alphabet, get_alphabet(FALSE /* Don't include ambigs */));
-  (*the_hmm)->ambigs = get_alph_size(AMBIG_SIZE);
-
   // Read and set the HMM type
   xpath_obj = xpath_query(xpath_ctxt, "/MEME_HMM");
   property = read_xml_node_property(xpath_obj->nodesetval->nodeTab[0], "type");
@@ -493,7 +487,7 @@ static void read_mhmm_from_xml(
   init_matrix(0.0, (*the_hmm)->trans);
 
   // Read all the states into the HMM
-  read_mhmm_states_from_xml(xpath_ctxt, *the_hmm);
+  read_mhmm_states_from_xml(alph, xpath_ctxt, *the_hmm);
 
   // Record the number of motifs.
   (*the_hmm)->num_motifs = get_num_motifs(*the_hmm);
@@ -502,16 +496,16 @@ static void read_mhmm_from_xml(
      it contains the alphabet plus ambiguous characters.  Hence
      the following shenanigans.  */
   {
-    ARRAY_T* background = read_bg_freqs_from_xml(xpath_ctxt);
+    ARRAY_T* background = read_bg_freqs_from_xml(xpath_ctxt, alph);
     int i = 0;
-    for (i = 0; i < get_alph_size(ALPH_SIZE); i++) {
+    for (i = 0; i < alph_size_core(alph); i++) {
       set_array_item(i, get_array_item(i, background), (*the_hmm)->background);
     }
     free_array(background);
   }
 
   // Fill in ambiguous characters.
-  fill_in_ambiguous_chars(FALSE, (*the_hmm)->background);
+  calc_ambigs(alph, false, (*the_hmm)->background);
 
 
 }
@@ -522,11 +516,11 @@ static void read_mhmm_from_xml(
  * IN: model_file - 
  * OUT: the_hmm - 
  *************************************************************************/
-BOOLEAN_T read_mhmm_xml_file(
+bool read_mhmm_xml_file(
   char*    model_filename, /* The name of the file to be read from. */
   MHMM_T** the_hmm         /* The HMM (not pre-allocated). */
 ) {
-
+  ALPH_T* alph;
   xmlParserCtxtPtr ctxt;         // The parser
   xmlDocPtr mhmm_doc;            // The document tree
   xmlXPathContextPtr xpath_ctxt; // XPath context
@@ -552,7 +546,7 @@ BOOLEAN_T read_mhmm_xml_file(
     if (verbosity > NORMAL_VERBOSE) {
       fprintf(stderr, "Failed to parse %s as an XML document.\n", model_filename);
     }
-    return FALSE;
+    return false;
   } else {
     // Did it validate as a MEME_HMM document?
     if (ctxt->valid == 0 || strcmp((char *) ctxt->intSubName, "MEME_HMM") != 0) {
@@ -570,13 +564,15 @@ BOOLEAN_T read_mhmm_xml_file(
   xpath_ctxt = xmlXPathNewContext(mhmm_doc);
 
   // Read and set alphabet
-  read_alphabet_from_xml(xpath_ctxt);
+  alph = read_alphabet_from_xml(xpath_ctxt);
 
   // Create an HMM struct from the XML struct.
-  read_mhmm_from_xml(xpath_ctxt, the_hmm);
+  read_mhmm_from_xml(alph, xpath_ctxt, the_hmm);
+
+  alph_release(alph);
 
   /* Compute the state-by-state incoming and outgoing transitions. */
-  compute_ins_and_outs(*the_hmm, FALSE);
+  compute_ins_and_outs(*the_hmm, false);
 
   /* free up the resulting document */
   xmlXPathFreeContext(xpath_ctxt);
@@ -584,7 +580,7 @@ BOOLEAN_T read_mhmm_xml_file(
   xmlFreeParserCtxt(ctxt);
   xmlCleanupParser();
 
-  return TRUE;
+  return true;
 
 }
 /*************************************************************************
@@ -599,23 +595,19 @@ void read_mhmm(
   char*    hmm_filename,  /* The file to be read from. */
   MHMM_T** the_hmm        /* The HMM (not pre-allocated). */
 ) {
-
+  ALPH_T* alph;
   char buffer[BUF_LENGTH];    /* Buffer for reading from file. */
   char version[BUF_LENGTH];   /* Buffer for reading from file. */
   int  type;          /* Type of model (MHMM or HMMER). */
   int  num_states;    /* Number of states in the model. */
   int  num_spacers;   /* Number of spacers in the model. */
   int  spacer_states; /* Number of states per spacer. */
-  int  alph_size;     /* Number of characters in the alphabet. */
+  int  asize;     /* Number of characters in the alphabet. */
   int  i_state;       /* Index of the current state. */
   ARRAY_T* motif_widths;	// Array to hold motif widths 
 
-  if (verbosity >= NORMAL_VERBOSE) {
-    fprintf(stderr, "Reading HMM: ");
-  }
-
   // Begin by assuming that it is an MHMM XML file.
-  BOOLEAN_T result = read_mhmm_xml_file(hmm_filename, the_hmm);
+  bool result = read_mhmm_xml_file(hmm_filename, the_hmm);
   if (result) {
     // If that worked, we're done!
     return;
@@ -623,7 +615,7 @@ void read_mhmm(
 
   // Open the file for reading.
   FILE* hmm_file;
-  if (open_file(hmm_filename, "r", TRUE, "HMM", "HMM", &hmm_file) == 0) {
+  if (open_file(hmm_filename, "r", true, "HMM", "HMM", &hmm_file) == 0) {
     exit(1);
   }
 
@@ -647,25 +639,23 @@ void read_mhmm(
   assert(num_scan == 1);
   num_scan = fscanf(hmm_file, " spacer_length: %d", &spacer_states);
   assert(num_scan == 1);
-  num_scan = fscanf(hmm_file, " alph_size: %d", &alph_size);
+  num_scan = fscanf(hmm_file, " alph_size: %d", &asize);
   assert(num_scan == 1);
 
   // Set up the alphabet.
   num_scan = fscanf(hmm_file, " alphabet: %s", buffer);
   assert(num_scan == 1);
-  set_alphabet(verbosity, buffer);
-
+  alph = alph_type(buffer, BUF_LENGTH);
+  if (alph == NULL) die("The mhmm alphabet was unrecognised.\n");
+  if (asize != alph_size_core(alph)) die("The mhmm alphabet %s does not "
+      "have %d letters\n", alph_name(alph), asize);
   // Allocate the HMM.
-  allocate_mhmm(num_states, the_hmm);
+  *the_hmm = allocate_mhmm(alph, num_states);
 
   // Store information that we have read so far.
   (*the_hmm)->type = type;
-  (*the_hmm)->num_states = num_states;
   (*the_hmm)->num_spacers = num_spacers;
   (*the_hmm)->spacer_states = spacer_states;
-  (*the_hmm)->alph_size = alph_size;
-  strcpy((*the_hmm)->alphabet, get_alphabet(FALSE));
-  (*the_hmm)->ambigs = get_alph_size(AMBIG_SIZE);
 
   // Read the background distribution.
   num_scan = fscanf(hmm_file, " background: ");
@@ -678,16 +668,16 @@ void read_mhmm(
     int i;
     ARRAY_T* background;
 
-    background = allocate_array(get_alph_size(ALPH_SIZE));
+    background = allocate_array(alph_size_core(alph));
     read_array(hmm_file, background);
-    for (i = 0; i < get_alph_size(ALPH_SIZE); i++) {
+    for (i = 0; i < alph_size_core(alph); i++) {
       set_array_item(i, get_array_item(i, background), (*the_hmm)->background);
     }
     free_array(background);
   }
 
   // Extend the distribution to account for ambiguous characters.
-  fill_in_ambiguous_chars(FALSE, (*the_hmm)->background);
+  calc_ambigs(alph, false, (*the_hmm)->background);
 
   // Read the optional fields.
   if (fscanf(hmm_file, " description: %[^\n]", buffer) == 1) {
@@ -704,8 +694,8 @@ void read_mhmm(
   motif_widths = allocate_array(num_states);  // tlb; need to set widths
   for (i_state = 0; i_state < num_states; i_state++) {
     if (verbosity >= NORMAL_VERBOSE)
-      fprintf(stderr, "%d\r", i_state);		// tlb; replace " " with \r
-    read_mhmm_state(hmm_file, i_state, &((*the_hmm)->states[i_state]));
+      fprintf(stderr, "\rReading HMM: %d", i_state);
+    read_mhmm_state(alph, hmm_file, i_state, &((*the_hmm)->states[i_state]));
     // Save motif width when you know it.
     if ((*the_hmm)->states[i_state].type == END_MOTIF_STATE) {
       set_array_item(
@@ -738,13 +728,20 @@ void read_mhmm(
 
   /* Read the transition matrix. */
   read_mhmm_trans(hmm_file, num_states, (*the_hmm)->trans);
-  assert(verify_trans_matrix(FALSE, num_states, (*the_hmm)->trans));
+  assert(verify_trans_matrix(false, num_states, (*the_hmm)->trans));
 
-  fscanf(hmm_file, " End of MHMM");
+  // note the original version of this only used the fscanf but it was 
+  // impossible to tell if the fscanf call worked because it had no fields.
+  if (fscanf(hmm_file, " End of %10s", buffer) != 1 || strcmp(buffer, "MHMM") != 0) {
+    die("Missing \"End of MHMM\"\n");
+  }
 
   /* Compute the state-by-state incoming and outgoing transitions. */
-  compute_ins_and_outs(*the_hmm, FALSE);
+  compute_ins_and_outs(*the_hmm, false);
 
+  // done with alphabet
+  alph_release(alph);
+ 
   fclose(hmm_file);
 
 } // read_mhmm
