@@ -7,6 +7,11 @@
  * DESCRIPTION: Remove from a tree all species not in the given alignment
  *              and vice versa.
  *************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include "alignment.h"
 #include "clustalw-io.h"
 #include "tree.h"
@@ -17,8 +22,6 @@
  *****************************************************************************/
 #ifdef MAIN
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 int main
   (int    argc,
    char * argv[])
