@@ -35,6 +35,9 @@ static void usage(char *format, ...) {
     "     --n <filename>            control (negative) sequence file name;\n"
     "                               defaults: if --n is not given, then SEA\n"
     "                               creates one by shuffling the primary sequences\n"
+    "     --notrim                  do not trim the control sequences even if their\n"
+    "                               average length is greater the than primary sequences;\n"
+    "                               default: trim control sequences if needed\n"
 /*
     "                               creates control sequences as follows:\n"
     "                                 <objfun> = de, shuffle primary sequences\n"
@@ -96,7 +99,7 @@ static void usage(char *format, ...) {
 // Be careful that there are not more than 62 options as otherwise the value
 // of '?' will be used.
 enum Opts {
-  OPT_M, OPT_P, OPT_N, OPT_ORDER, OPT_O, OPT_OC, OPT_TEXT, //OPT_OBJFUN,
+  OPT_M, OPT_P, OPT_N, OPT_NOTRIM, OPT_ORDER, OPT_O, OPT_OC, OPT_TEXT, //OPT_OBJFUN,
   OPT_XALPH, OPT_BFILE, OPT_PSEUDOCOUNT, OPT_INC, OPT_EXC,
   OPT_HOFRACT, OPT_SEED, OPT_THRESH, OPT_QVALUE, OPT_PVALUE, OPT_DISTR, OPT_ALIGN,
   OPT_NOSEQS, OPT_DESC, OPT_DFILE, OPT_VERBOSITY, OPT_VERSION
@@ -111,6 +114,7 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
     {"m", required_argument, NULL, OPT_M},
     {"p", required_argument, NULL, OPT_P},
     {"n", required_argument, NULL, OPT_N},
+    {"notrim", no_argument, NULL, OPT_NOTRIM},
     {"order", required_argument, NULL, OPT_ORDER},
     {"o", required_argument, NULL, OPT_O},
     {"oc", required_argument, NULL, OPT_OC},
@@ -143,6 +147,7 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
   options->text_only = false;
   options->posfile = NULL;
   options->negfile = NULL;
+  options->notrim = false;
   //options->objfun = DEFAULT_OBJFUN;
   options->order = -1;			// flags no option given
   options->alphabet_type = DEFAULT_ALPHABET_TYPE;
@@ -191,6 +196,9 @@ static char *process_command_line(int argc, char* argv[], STREME_OPTIONS_T *opti
       case OPT_N:
         options->negfile = optarg;
         break;
+      case OPT_NOTRIM:
+        options->notrim = true;
+        break;
 #ifdef EXP
       case OPT_OBJFUN:
         if (! strcmp(optarg, "de")) {
@@ -737,6 +745,7 @@ static void output_results(
       : "Central Distance");
     jsonwr_lng_prop(json_output, "order", options->order);
     jsonwr_lng_prop(json_output, "seed", options->seed);
+    jsonwr_bool_prop(json_output, "notrim", options->notrim);
     jsonwr_dbl_prop(json_output, "pseudocount", options->pseudocount);
     jsonwr_str_prop(json_output, "thresh_type", options->thresh_type == 
       EVALUE ?  "evalue" : (options->thresh_type == QVALUE ? "qvalue" : "pvalue")
@@ -746,7 +755,7 @@ static void output_results(
     jsonwr_bool_prop(json_output, "is_holdout", is_holdout);
     jsonwr_str_prop(json_output, "strands", (do_rc) ? "both" : "given");
     jsonwr_str_prop(json_output, "align", options->align_txt);
-    jsonwr_str_prop(json_output, "noseqs", options->noseqs ? "true" : "false");
+    jsonwr_bool_prop(json_output, "noseqs", options->noseqs);
     jsonwr_end_object_value(json_output);
 
     // output the motif dbs
@@ -903,7 +912,7 @@ static void output_results(
 	// Free the matches in the model.
 	free(model->matches);
 	// Score the second set of sequences getting just the ZOOPS sites (ignores score threshold).
-	score_model_pssm(options, train_multiseq, model, false, false, ZOOPS, false, false);
+	score_model_pssm(options, train_multiseq, model, false, false, ZOOPS, false, false, false);
 	get_passing_sequences(options, model, train_multiseq, true, true);
       }
       print_passing_sequences_tsv(options, dbs, model, imotif);
@@ -1014,7 +1023,7 @@ int main(int argc, char *argv[])
   // Note that we are swapping the training and hold-out sets here relative to STREME.
   options.nmotifs = 1;	// suppress warning message
   Multiseq *train_multiseq = NULL;
-  Multiseq *test_multiseq = read_pos_neg_seqs(&options, do_rc, false, false, true, back, &train_multiseq);
+  Multiseq *test_multiseq = read_pos_neg_seqs(&options, do_rc, True, false, options.notrim, true, back, &train_multiseq);
   if (train_multiseq) set_logcumback(&options, train_multiseq);
   set_logcumback(&options, test_multiseq);
 
@@ -1040,10 +1049,10 @@ int main(int argc, char *argv[])
       model->db_idx = db_i;
       // Score the motif on the training set (small) to get score threshold.
       // Don't use the cache.
-      if (train_multiseq) score_model_pssm(&options, train_multiseq, model, true, false, NONE, false, false);
+      if (train_multiseq) score_model_pssm(&options, train_multiseq, model, true, false, NONE, false, false, false);
       // Score the motif on the hold-out set (big) using the computed threshold if there is one.
       // Use the cache for speed.  Save all passing matches.
-      score_model_pssm(&options, test_multiseq, model, !train_multiseq, true, PASSING, true, true);
+      score_model_pssm(&options, test_multiseq, model, !train_multiseq, true, PASSING, true, true, false);
       // Adjust for multiple tests if the score threshold was optimized on the test set.
       if (!train_multiseq) model->test_log_pvalue = LOGEV(log(model->n_eff_tests), model->test_log_pvalue);
       // Compute the E-value.
