@@ -11,6 +11,7 @@
 #include <limits.h>
 #include <string.h>
 #include "alphabet.h"
+#include "macros.h"
 #include "utils.h"
 #include "ushuffle.h"
 #include "seq.h"
@@ -60,7 +61,7 @@ SEQ_T* allocate_seq(
   new_sequence->starting_coord = offset;
   new_sequence->weight = 1.0;
   new_sequence->is_complete = false;
-  new_sequence->num_priors = 0;
+  //new_sequence->num_priors = 0;
   new_sequence->total_gc = 0;
   new_sequence->sequence = NULL;
   new_sequence->isequence = NULL;
@@ -73,9 +74,11 @@ SEQ_T* allocate_seq(
   if (name != NULL) {
     strncpy(new_sequence->name, name, MAX_SEQ_NAME);
     new_sequence->name[MAX_SEQ_NAME] = '\0';
-    if (strlen(new_sequence->name) != strlen(name)) {
-      fprintf(stderr, "Warning: truncating sequence ID %s to %s.\n",
-          name, new_sequence->name);
+    if (verbosity >= NORMAL_VERBOSE) {
+      if (strlen(new_sequence->name) != strlen(name)) {
+	fprintf(stderr, "Warning: truncating sequence ID %s to %s.\n",
+	    name, new_sequence->name);
+      }
     }
   }
 
@@ -284,16 +287,6 @@ void set_total_gc_sequence
   a_sequence->total_gc = gc;
 }
 
-/**************************************************************************
- * Return the number of priors currently stored in the SEQ_T object
- **************************************************************************/
-unsigned int get_seq_num_priors
-  (SEQ_T* a_sequence)
-{
-  assert(a_sequence != NULL);
-  return(a_sequence->num_priors);
-}
-
 /**************************************************************************
  * Return a pointer to the priors associated with a SEQ_T object.
  * It may be a NULL pointer. If it is not NULL the number of priors
@@ -486,9 +479,9 @@ void remove_flanking_xs
  * the index of that character in the alphabet. 
  **************************************************************************/
 void prepare_sequence (
-    SEQ_T* sequence, 
-    ALPH_T* alph,
-    bool hard_mask
+  SEQ_T* sequence, 
+  ALPH_T* alph,
+  bool hard_mask
 )
 {
   int i_seq;        // Index in the sequence.
@@ -519,14 +512,17 @@ void prepare_sequence (
 
   // Tell the user about the conversions.
   if (maskedchar) {
-    fprintf(stderr, "Warning: converted %d lower-case (masked) ", maskedchar);
-    fprintf(stderr, "characters to %c in sequence %s.\n", wildcard, 
-      get_seq_name(sequence));
+    if (verbosity >= NORMAL_VERBOSE) {
+      fprintf(stderr, "Warning: converted %d lower-case (masked) ", maskedchar);
+      fprintf(stderr, "characters to %c in sequence %s.\n", wildcard, get_seq_name(sequence));
+    }
   }
   if (badchar) {
-    fprintf(stderr, "Warning: converted %d non-alphabetic ", badchar);
-    fprintf(stderr, "characters to %c in sequence %s.\n", wildcard, 
-      get_seq_name(sequence));
+    if (verbosity >= NORMAL_VERBOSE) {
+      fprintf(stderr, "Warning: converted %d non-alphabetic ", badchar);
+      fprintf(stderr, "characters to %c in sequence %s.\n", wildcard, 
+	get_seq_name(sequence));
+    }
   }
 
   // Add flanking X's.
