@@ -963,6 +963,7 @@ void reduce_across_heaps(
 
     // create the derived type
     MPI_Type_create_struct(SEED_PACKET_LENGTH, block_lengths, displacements, typelist, &seed_packet_type);
+    SEED_PACKET_TYPE_PTR = &seed_packet_type;
 
     // commit the derived type
     MPI_Type_commit(&seed_packet_type);
@@ -1024,10 +1025,11 @@ void reduce_across_heaps(
     // print the packets after the reduction
     if (NODE_NO >= 0 && mpMyID() == NODE_NO){
       fprintf(stdout, "AFTER\n");
-      for (i_packet = 0; i_packet < max_heap_size; i_packet++)
+      for (i_packet = 0; i_packet < max_heap_size; i_packet++) {
         fprintf(stdout, "AFTER node %d packet %d score= %g width= %i seed= %s iseq %d ioff %d nsites0= %d\n",
                        mpMyID(), i_packet, best_packets[i_packet].score,
                        best_packets[i_packet].width, best_packets[i_packet].seed, best_packets[i_packet].iseq, best_packets[i_packet].ipos, best_packets[i_packet].nsites0);
+      }
       fflush(stdout);
     }
 
