@@ -76,27 +76,27 @@ struct streme_io_xml_callbacks {
   void (*end_streme)(void *ctx);
 
 /*****************************************************************************
- * streme > model
+ * STREME > model
  * contains: command_line, train_positives, train_negatives, test_positives,
- *          test_negatives, sequence_db, alphabet, strands, background,
+ *          test_negatives, alphabet, strands, sequence_db, background_frequencies,
  *          stop, objfun, srch, test, minw, maxw, kmer, hofract, neval, nref,
  *          niter, mmr, seed, host
  ****************************************************************************/
   void (*start_model)(void *ctx);
 
 /*****************************************************************************
- * streme > /model
+ * STREME > /model
  ****************************************************************************/
   void (*end_model)(void *ctx);
 
 /*****************************************************************************
- * streme > model > command_line
+ * STREME > model > command_line
  * the command-line used to run the program.
  ****************************************************************************/
   void (*handle_command_line)(void *ctx, char *command_line);
 
 /*****************************************************************************
- * streme > model > train_positives
+ * STREME > model > train_positives
  *
  *  count           the number of sequences in the positive input set
  *  positions       the number of characters in the positive training set
@@ -106,7 +106,7 @@ struct streme_io_xml_callbacks {
       char *positives_file_path);
 
 /*****************************************************************************
- * streme > model > train_negatives
+ * STREME > model > train_negatives
  *
  *  count           the number of sequences in the negative dataset
  *  positions       the number of characters in the negative training set
@@ -117,7 +117,7 @@ struct streme_io_xml_callbacks {
       STREME_NEG_EN negatives_source, char *negatives_file_path);
 
 /*****************************************************************************
- * streme > model > test_positives
+ * STREME > model > test_positives
  *
  *  count           the number of sequences in the positive training set
  *  positions       the number of characters in the positive training set
@@ -125,7 +125,7 @@ struct streme_io_xml_callbacks {
   void (*handle_test_positives) (void *ctx, long sequence_count, long sequence_positions);
 
 /*****************************************************************************
- * streme > model > test_negatives
+ * STREME > model > test_negatives
  *
  *  count           the number of sequences in the negative training set
  *  positions       the number of characters in the negative training set
@@ -133,14 +133,14 @@ struct streme_io_xml_callbacks {
   void (*handle_test_negatives) (void *ctx, long sequence_count, long sequence_positions);
 
 /*****************************************************************************
- * streme > model > sequence_db
+ * STREME > model > sequence_db
  *
  *  This is a dummy entry with no contents.
  ****************************************************************************/
   void (*handle_sequence_db) (void *ctx, int dummy);
 
 /*****************************************************************************
- * streme > model > alphabet
+ * STREME > model > alphabet
  *
  *  name            is the name of the alphabet
  *  extends_flags   is the alphabet being extended or 0
@@ -148,14 +148,14 @@ struct streme_io_xml_callbacks {
   void (*start_alphabet) (void *ctx, char *name, int extends_flags);
 
 /*****************************************************************************
- * streme > model > /alphabet
+ * STREME > model > /alphabet
  *
  *  name            is the name of the alphabet
  ****************************************************************************/
   void (*end_alphabet) (void *ctx);
 
 /*****************************************************************************
- * streme > model > alphabet > letter
+ * STREME > model > alphabet > letter
  *
  *  id              the identifier used to represent the symbol as XML attributes
  *  symbol          the symbol
@@ -169,14 +169,14 @@ struct streme_io_xml_callbacks {
       char *aliases, char complement, char *equals, char *name, int color);
 
 /*****************************************************************************
- * streme > model > strands
+ * STREME > model > strands
  *
  *  strands         how is streme handling the strands
  ****************************************************************************/
   void (*handle_strands) (void *ctx, STREME_STRANDS_EN strands);
 
 /*****************************************************************************
- * streme > model > background
+ * STREME > model > background
  *
  *  nfreqs          is the count of frequencies (same as alphabet core size)
  *  freqs           is the array of frequencies (ordered as in alphabet core)
@@ -185,8 +185,18 @@ struct streme_io_xml_callbacks {
   void (*handle_background) (void *ctx, int nfreqs, double* freqs, 
       STREME_BG_EN background_source);
 
+  void (*start_background_frequencies)(void *, char *); // source of data
+  void (*end_background_frequencies)(void *);
+  //start background frequencies
+  void (*start_bf_alphabet_array)(void *);
+  void (*end_bf_alphabet_array)(void *);
+  //start alphabet_array
+  void (*handle_bf_aa_value)(void *, char *, double);
+  //end alphabet_array
+  //end background frequencies
+
 /*****************************************************************************
- * streme > model > stop
+ * STREME > model > stop
  *
  *  pvt         the maximum p-value threshold for motifs
  *  nmotifs     the maximum number of motifs to find
@@ -195,124 +205,139 @@ struct streme_io_xml_callbacks {
   void (*handle_stop) (void *ctx, double pvt, int nmotifs, double time);
 
 /*****************************************************************************
- * streme > model > objfun
+ * STREME > model > objfun
  ****************************************************************************/
   void (*handle_objfun) (void *ctx, STREME_OBJFUN_EN objfun);
 
 /*****************************************************************************
- * streme > model > test 
+ * STREME > model > test 
  ****************************************************************************/
   void (*handle_test) (void *ctx, STREME_TEST_EN test);
 
 /*****************************************************************************
- * streme > model > minw
+ * STREME > model > minw
  ****************************************************************************/
   void (*handle_minw) (void *ctx, int minw);
 
 /*****************************************************************************
- * streme > model > maxw
+ * STREME > model > maxw
  ****************************************************************************/
   void (*handle_maxw) (void *ctx, int maxw);
 
 /*****************************************************************************
- * streme > model > kmer 
+ * STREME > model > kmer 
  ****************************************************************************/
   void (*handle_kmer) (void *ctx, int kmer);
 
 /*****************************************************************************
- * streme > model > hofract
+ * STREME > model > hofract
  ****************************************************************************/
   void (*handle_hofract) (void *ctx, double hofract);
 
 /*****************************************************************************
- * streme > model > neval 
+ * STREME > model > neval 
  ****************************************************************************/
   void (*handle_neval) (void *ctx, int neval);
 
 /*****************************************************************************
- * streme > model > nref 
+ * STREME > model > nref 
  ****************************************************************************/
   void (*handle_nref) (void *ctx, int nref);
 
 /*****************************************************************************
- * streme > model > niter 
+ * STREME > model > niter 
  ****************************************************************************/
   void (*handle_niter) (void *ctx, int niter);
 
 /*****************************************************************************
- * streme > model > patience
+ * STREME > model > patience
  ****************************************************************************/
   void (*handle_patience) (void *ctx, long patience);
 
 /*****************************************************************************
- * streme > model > seed 
+ * STREME > model > seed 
  ****************************************************************************/
   void (*handle_seed) (void *ctx, long seed);
 
 /*****************************************************************************
- * streme > model > useer
+ * STREME > model > notrim		New in 5.5.3
+ ****************************************************************************/
+  void (*handle_notrim) (void *ctx, int notrim);
+
+/*****************************************************************************
+ * STREME > model > useer
  ****************************************************************************/
   void (*handle_useer) (void *ctx, int useer);
 
 /*****************************************************************************
- * streme > model > minscore
+ * STREME > model > minscore
  ****************************************************************************/
   void (*handle_minscore) (void *ctx, long minscore);
 
 /*****************************************************************************
- * streme > model > ignore_depth
+ * STREME > model > ignore_depth
  ****************************************************************************/
   void (*handle_ignore_depth) (void *ctx, long ignore_depth);
 
 /*****************************************************************************
- * streme > model > nsubsets 
+ * STREME > model > nsubsets 
  ****************************************************************************/
   void (*handle_nsubsets) (void *ctx, long nsubsets);
 
 /*****************************************************************************
- * streme > model > min_pal_ratio
+ * STREME > model > min_pal_ratio
  ****************************************************************************/
   void (*handle_min_pal_ratio) (void *ctx, double min_pal_ratio);
 
 /*****************************************************************************
- * streme > model > max_pal_ed
+ * STREME > model > max_pal_ed
  ****************************************************************************/
   void (*handle_max_pal_ed) (void *ctx, double max_pal_ed);
 
 /*****************************************************************************
- * streme > model > cand 
+ * STREME > model > cand 
  ****************************************************************************/
   void (*handle_cand) (void *ctx, int cand);
 
 /*****************************************************************************
- * streme > model > experimental
+ * STREME > model > experimental
  ****************************************************************************/
   void (*handle_experimental) (void *ctx, int experimental);
 
 /*****************************************************************************
- * streme > model > totallength
+ * STREME > model > totallength
  ****************************************************************************/
   void (*handle_totallength) (void *ctx, long totallength);
 
 /*****************************************************************************
- * streme > model > host 
+ * STREME > model > align
+ ****************************************************************************/
+  void (*handle_align) (void *ctx, long align);
+
+/*****************************************************************************
+ * STREME > model > host 
  ****************************************************************************/
   void (*handle_host) (void *ctx, char *host);
 
 /*****************************************************************************
- * streme > motifs
+ * STREME > model > description
+ ****************************************************************************/
+  void (*handle_description)(void *ctx, char *experiment_description);
+
+/*****************************************************************************
+ * STREME > motifs
  * contains: motif*
  ****************************************************************************/
   void (*start_motifs)(void *ctx);
 
 /*****************************************************************************
- * streme > /motifs
+ * STREME > /motifs
  * contains: motif*
  ****************************************************************************/
   void (*end_motifs)(void *ctx);
 
 /*****************************************************************************
- * streme > motifs > motif
+ * STREME > motifs > motif
  *
  *  id                the identifier used by STREME
  *  alt               alternate identifier used by STREME
@@ -342,13 +367,13 @@ struct streme_io_xml_callbacks {
     char *is_palindromic, double elapsed_time);
 
 /*****************************************************************************
- * streme > motifs > /motif
+ * STREME > motifs > /motif
  * contains: pos+, match*
  ****************************************************************************/
   void (*end_motif)(void *ctx);
 
 /*****************************************************************************
- * streme > motifs > motif > pos
+ * STREME > motifs > motif > pos
  *
  *  position          index of the motif position
  *  nfreqs            number of frequencies
@@ -357,12 +382,12 @@ struct streme_io_xml_callbacks {
   void (*handle_pos)(void *ctx, int position, int nfreqs, double* freqs);
 
 /*****************************************************************************
- * streme > reason_for_stopping
+ * STREME > reason_for_stopping
  ****************************************************************************/
   void (*handle_reason_for_stopping)(void *ctx, char *reason_for_stopping);
 
 /*****************************************************************************
- * streme > run_time
+ * STREME > run_time
  *
  *  cpu             the time the program was running on a cpu.
  ****************************************************************************/
