@@ -202,7 +202,7 @@ void shuffle_multiseq(
 Multiseq *read_pos_neg_seqs(
   STREME_OPTIONS_T *options,
   BOOL do_rc,				// append reverse complement of pos+neg sequences
-					// negative sequences by shuffling positive sequences
+  BOOL use_smaller_strand,		// ensure results are independent of strand
   BOOL allow_ambigs,			// don't convert ambiguous characters to SEPARATOR
   BOOL no_trim,				// don't trim sequences to average length
   BOOL set_back,			// set the background in the multiseq objects
@@ -214,7 +214,7 @@ Multiseq *read_pos_neg_seqs(
   ALPH_T *alph = options->alph;		// the sequence alphabet
   ALPHABET_T alphabet_type = options->alphabet_type;
   int order = options->order;		// shuffle using m-order shuffle
-  double hofract = options->hofract;	// size of test set
+  double hofract = options->hofract;	// size of test set; none if <=0; -1 means don't set nmotifs
   int minwidth = options->minwidth;	// mininum motif width
   int maxtotallength = options->totallength;	// truncate each each sequence set (+/-) to this length
   Multiseq *multiseq=NULL, *test_multiseq=NULL, *negmultiseq=NULL, *test_negmultiseq=NULL;
@@ -224,7 +224,8 @@ Multiseq *read_pos_neg_seqs(
   if (is_rna) DEBUG_MSG(NORMAL_VERBOSE, "# NOTE: Will convert any DNA sequences to RNA.\n");
 
   // Read in the positive sequences.
-  if (read_fasta_to_multiseqs(&multiseq, &test_multiseq, hofract, MIN_HO_SIZE, do_rc, is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
+  if (read_fasta_to_multiseqs(&multiseq, &test_multiseq, hofract, MIN_HO_SIZE, do_rc, use_smaller_strand, 
+       is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
     DEBUG_FMT(QUIET_VERBOSE, "ERROR: There was a problem reading the primary sequence file '%s'.\n", posfile); 
     exit(EXIT_FAILURE);
   }
@@ -245,7 +246,8 @@ Multiseq *read_pos_neg_seqs(
 
   // Read in the negative sequences if needed.
   if (options->objfun == DE || options->objfun == NO_OBJFUN) {
-    if (read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : hofract), MIN_HO_SIZE, do_rc, is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
+    if (read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : hofract), MIN_HO_SIZE, do_rc, use_smaller_strand,
+      is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
       DEBUG_FMT(QUIET_VERBOSE, "ERROR: There was a problem reading the control sequence file '%s'.\n", negfile); 
       exit(EXIT_FAILURE);
     }
@@ -259,8 +261,10 @@ Multiseq *read_pos_neg_seqs(
       freemultiseq(multiseq);
       freemultiseq(test_multiseq);
       freemultiseq(negmultiseq);
-      (void) read_fasta_to_multiseqs(&multiseq, &test_multiseq, 0, MIN_HO_SIZE, do_rc, is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength);
-      (void) read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : 0), MIN_HO_SIZE, do_rc, is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength);
+      (void) read_fasta_to_multiseqs(&multiseq, &test_multiseq, 0, MIN_HO_SIZE, do_rc, use_smaller_strand,
+        is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength);
+      (void) read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : 0), MIN_HO_SIZE, do_rc, use_smaller_strand,
+        is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength);
     }
   }
 
@@ -309,12 +313,14 @@ Multiseq *read_pos_neg_seqs(
 
   // Append the training negative sequences to the training positive sequences
   // trimming the negatives if they have longer average length.
+  BOOL train_neg_trimmed = false;
+  BOOL test_neg_trimmed = false;
   if (negmultiseq) {
-    append_to_multiseq(multiseq, negmultiseq, no_trim, false);
+    train_neg_trimmed = append_to_multiseq(multiseq, negmultiseq, no_trim, false);
     freemultiseq(negmultiseq);
     // Append the hold-out negative sequences to the hold-out training positive sequences.
     if (test_multiseq) {
-      append_to_multiseq(test_multiseq, test_negmultiseq, no_trim, true);
+      test_neg_trimmed = append_to_multiseq(test_multiseq, test_negmultiseq, no_trim, true);
       freemultiseq(test_negmultiseq);
     }
   } else {
@@ -327,7 +333,7 @@ Multiseq *read_pos_neg_seqs(
   }
 
   // Ignore <pvt> if there is no hold-out set for computing unbiased p-values.
-  if (test_multiseq == NULL && options->nmotifs == 0) {
+  if (options->hofract >= 0 && test_multiseq == NULL && options->nmotifs == 0) {
     DEBUG_FMT(QUIET_VERBOSE, "# Warning: Ignoring <thresh> (%g) and setting <nmotifs> to %d.\n", options->thresh, DEFAULT_NMOTIFS);
     options->nmotifs = DEFAULT_NMOTIFS;
     options->thresh = DEFAULT_EVT;
@@ -380,26 +386,34 @@ Multiseq *read_pos_neg_seqs(
 
     // Use Binomial Test or Fisher Exact Test with DE objective function?
     // We use the Fisher Exact Test unless the average lengths of
-    // the main positive and negative sequences differ by >= 0.01% of the length
-    // of the main positives.
+    // the positive and negative sequences differ by >= 0.01% of the length
+    // of the positive sequencs or of the negative sequences.
     if (options->objfun == DE) {
-      if (mseq == multiseq) {
-	double diff = fabs(mseq->avg_poslen - mseq->avg_neglen)/mseq->avg_poslen;
-	if (diff >= 0.0001) {
-          multiseq->use_binomial = true;
-	  // Note: this is a compromise over all motif widths.
-	  double avg_w = (options->minwidth + options->maxwidth) / 2.0;
-	  double pos_sites = mseq->npos * MAX(1, (mseq->avg_poslen - avg_w + 1));
-	  double neg_sites = mseq->nneg * MAX(1, (mseq->avg_neglen - avg_w + 1));
-	  multiseq->bernoulli = pos_sites / (pos_sites + neg_sites);
+      // Set the Bernoulli probability in case needed.
+      // Note: this is a compromise over all motif widths.
+      double avg_w = (options->minwidth + options->maxwidth) / 2.0;
+      double pos_sites = mseq->npos * MAX(1, (mseq->avg_poslen - avg_w + 1));
+      double neg_sites = mseq->nneg * MAX(1, (mseq->avg_neglen - avg_w + 1));
+      mseq->bernoulli = pos_sites / (pos_sites + neg_sites);
+      double diff1 = fabs(mseq->avg_poslen - mseq->avg_neglen)/mseq->avg_poslen;
+      double diff2 = mseq->avg_neglen > 0 ? fabs(mseq->avg_poslen - mseq->avg_neglen)/mseq->avg_neglen : 0;
+      // Check if trimming of controls failed.
+      if (diff1 >= 0.0001 || diff2 >= 0.0001) {
+	mseq->use_binomial = true;
+        if (mseq == multiseq) {
+	  if (train_neg_trimmed) DEBUG_MSG(NORMAL_VERBOSE, "# The trimming of control non-hold-out sequences to within 0.01%% of average primary length was not possible.\n");
+        } else {
+	  if (test_neg_trimmed) DEBUG_MSG(NORMAL_VERBOSE, "# The trimming of control hold-out sequences to within 0.01%% of average primary length was not possible.\n");
         }
-      } else {
-        // Set the test sequences to use the same test as the main sequences.
-        test_multiseq->use_binomial = multiseq->use_binomial;
-	test_multiseq->bernoulli = multiseq->bernoulli;
       }
     }
   }
+  // Use Binomial Test for training sequences if the test sequences require it.
+  // Use same Bernoulli probability for both sets.
+  if (test_multiseq && test_multiseq->use_binomial) {
+    multiseq->use_binomial = true;
+    test_multiseq->bernoulli = multiseq->bernoulli;
+  }
  
   // Check that sequence lengths are OK for objective function.
   if (options->objfun == CD && 
@@ -416,8 +430,8 @@ Multiseq *read_pos_neg_seqs(
   if (options->objfun == DE) {
     if (multiseq->use_binomial) {
       DEBUG_FMT(NORMAL_VERBOSE, 
-        "# Using Binomial test for p-values because primary and control sequences\n"
-        "# have different average lengths: %g vs. %g. Bernoulli = %f\n",
+        "# Using Binomial test for p-values because primary and control sequences have\n"
+        "#   different average lengths: %g vs. %g. Bernoulli = %f\n",
         multiseq->avg_poslen, multiseq->avg_neglen, multiseq->bernoulli);
       DEBUG_MSG(QUIET_VERBOSE, 
         "# Warning: p-values will be inaccurate if primary and control\n"
@@ -455,7 +469,8 @@ void score_model_pssm(
 					// PASSING: save all matches with score >= model->score_threshold for erasing
 					// NONE: don't save matches
   BOOL is_ho, 				// data is the hold-out set
-  BOOL use_cache  			// use the p-value cache
+  BOOL use_cache,  			// use the p-value cache
+  BOOL pos_only				// just score the positive sequences
 ) {
   Uint i, j, seqno, pos, rc_pos;
   OBJFUN_T objfun = options->objfun;
@@ -466,7 +481,7 @@ void score_model_pssm(
   double avg_neglen = multiseq->avg_neglen;
   Uint npos = multiseq->npos;
   Uint nneg = multiseq->nneg;
-  Uint ntot = npos + nneg;
+  Uint ntot = npos + (pos_only ? 0 : nneg);
   BOOL use_binomial = multiseq->use_binomial;
   int bg_order = multiseq->bg_order;
   double *background = multiseq->background;
@@ -540,8 +555,8 @@ void score_model_pssm(
           if (do_rc) rc_score += rc_score_adj;
         }
         // Round the score(s) so sorting will be consistent across platforms.
-        RND(score, RNDDIG, score);
-        if (do_rc) RND(rc_score, RNDDIG, rc_score);
+        RND(score, STREME_RND, score);
+        if (do_rc) RND(rc_score, STREME_RND, rc_score);
         if (do_rc && rc_score > score) {
           score = rc_score;
           strand = '-';
@@ -749,6 +764,28 @@ int compare_site_score(
   }
 } // compare_site_score
 
+//
+// For sorting sites by sequence number, site position.
+//
+int compare_site_seq_pos(
+  const void *v1,
+  const void *v2
+)
+{
+  const Site *s1 = (const Site *) v1;
+  const Site *s2 = (const Site *) v2;
+
+  if (s1->seqno > s2->seqno) {
+    return(+1);
+  } else if (s1->seqno < s2->seqno) {
+    return(-1);
+  } else if (s1->pos > s2->pos) {
+    return(+1);
+  } else {
+    return(-1);
+  }
+} // compare_site_seq_pos
+
 //
 // For sorting sequences by decreasing score.
 //
@@ -862,8 +899,9 @@ void print_multiseq(
 // of the positive sequences in a multisequence object.
 // If the average length of the negative sequences is longer,
 // they are centrally trimmed to have the same average length.
+// Returns true if the sequences were trimmed.
 //
-void append_to_multiseq(
+BOOL append_to_multiseq(
   Multiseq *multiseq, 		// old sequences
   Multiseq *multiseq2,		// sequences to append
   BOOL no_trim,			// don't trim sequences to average length
@@ -873,14 +911,22 @@ void append_to_multiseq(
   Uint numofsequences = multiseq->numofsequences + multiseq2->numofsequences;
   Uint totallength = multiseq->totallength + multiseq2->totallength + 1;
   Uint neglength;
+  BOOL trimmed = false;
 
   // Trim the second set of sequences if they are longer (on average).
-  double avglen = (multiseq->totallength - multiseq->numofsequences + 1.0) / multiseq->numofsequences;
-  double avglen2 = (multiseq2->totallength - multiseq2->numofsequences + 1.0) / multiseq2->numofsequences;
-  double trim_fraction = no_trim ? 1 : ((avglen2 > avglen) ? avglen/avglen2 : 1);
-  if (trim_fraction != 1) 
-    DEBUG_FMT(NORMAL_VERBOSE, "# Trimming control %ssequences by %.2f%% to average primary sequence length (%.1f).\n", 
-      is_ho ? "holdout " : "", 100*(1-trim_fraction), avglen);
+  Uint len1 = (multiseq->totallength - multiseq->numofsequences + 1.0);
+  Uint len2 = (multiseq2->totallength - multiseq2->numofsequences + 1.0);
+  Uint n1 = multiseq->numofsequences;
+  Uint n2 = multiseq2->numofsequences;
+  double avglen1 = (double) len1 / n1;
+  double avglen2 = (double) len2 / n2;
+  double keep_fraction = no_trim ? 1 : ((avglen2 > avglen1) ? avglen1/avglen2 : 1);
+  double trim_fraction = 1 - keep_fraction;		// fraction to remove
+  Uint new_len2 = keep_fraction==1 ? len2 : avglen1 * n2;
+  if (keep_fraction != 1) {
+    DEBUG_FMT(NORMAL_VERBOSE, "# Attempting to trim control %ssequences by %.2f%% to average primary sequence length (%.1f).\n", 
+      is_ho ? "hold-out " : "", 100*trim_fraction, avglen1);
+  }
 
   // Append the new sequence descriptions.
   Uint index_offset = TOPINDEXARRAY(&(multiseq->descspace), Uchar) + 1;
@@ -911,7 +957,8 @@ void append_to_multiseq(
   PUSHARRAY(&multiseq->markpos, Uint, 128, multiseq->totallength);
   
   // Append the new sequence to the new space, trimming if requested.
-  if (trim_fraction == 1) {
+  if (keep_fraction == 1) {
+    trimmed = false;
     // Not trimming the new sequences.
     memcpy(sequence, multiseq2->sequence, multiseq2->totallength*sizeof(Uchar));
     // Append the markpos for each of the new sequences.
@@ -920,7 +967,10 @@ void append_to_multiseq(
     }
     multiseq->neg_length = multiseq2->totallength;
   } else {
+    trimmed = true;
     // Trimming the new sequences.
+    Uint final_len2 = 0;
+    Uint remain_len = len2 - new_len2;
     totallength = multiseq->totallength + 1;
     Uint seqno;
     for (seqno = 0; seqno < multiseq2->numofsequences; seqno++) {
@@ -929,12 +979,17 @@ void append_to_multiseq(
       Uint *markposptr = PEEKARRAY(&multiseq2->markpos, seqno, Uint);
       Uint seqend = (markposptr == NULL) ? multiseq2->totallength : *markposptr;
       Uint seqlen = seqend - seqstart;
-      Uint trimlen = MAX(1, trim_fraction * seqlen + 0.5);
+      // Always trim at least one position unless we've reached the desired length.
+      // Don't trim any more if we have reached the desired length.
+      Uint trimlen = MIN(remain_len, MAX(1, trim_fraction * seqlen + 0.5));
+      Uint keeplen = seqlen - trimlen;
       // Trim keeping the center of the new sequence and append it.
-      Uint offset = (seqlen - trimlen)/2.0;
-      memcpy(sequence, multiseq2->sequence + seqstart + offset, trimlen*sizeof(Uchar));
-      sequence += trimlen;
-      totallength += trimlen;
+      Uint offset = (seqlen - keeplen)/2.0;
+      memcpy(sequence, multiseq2->sequence + seqstart + offset, keeplen*sizeof(Uchar));
+      sequence += keeplen;
+      totallength += keeplen;
+      remain_len -= trimlen;
+      final_len2 += keeplen;
       // Add a separator and mark it unless this is the last sequence.
       if (seqno < multiseq2->numofsequences-1) {
 	*sequence++ = SEPARATOR;
@@ -946,6 +1001,8 @@ void append_to_multiseq(
 
   multiseq->totallength = totallength;
   multiseq->numofsequences = numofsequences;
+
+  return trimmed;
 } // append_to_multiseq
 
 //
@@ -1056,7 +1113,7 @@ void get_passing_sequences(
     seqno = model->matches[i].seqno;
     double score = model->matches[i].score;
     if (score >= score_threshold && score > best_score[seqno]) {
-      if (best_score[seqno] < score_threshold) npassing++;
+      if (best_score[seqno] < score_threshold) npassing++;	// first passing score
       best_score[seqno] = score;
     }
   }
