@@ -85,7 +85,7 @@ void mmcheckspaceleak(void);
 // Size of p-value cache in doubles.
 #define MAX_CACHE_SIZE 10000000
 
-#define FLOAT_EPS 1e-10
+#define FLOAT_EPS 1e-6
 
 // Number of significant digits after rounding.
 #define STREME_RND 10
@@ -143,7 +143,6 @@ DEXTERN(double, DEFAULT_PSEUDOCOUNT, 0);
 DEXTERN(double, DEFAULT_LOG_PVALUE, 0);
 DEXTERN(int, DEFAULT_CCUT, 0);
 DEXTERN(int, DEFAULT_VERBOSITY, NORMAL_VERBOSE);
-DEXTERN(VERBOSE_T, verbosity, NORMAL_VERBOSE);	// for MEME routines
 
 // The alphabets.
 DEXTERN(char*, DNA, "ACGT");
@@ -335,7 +334,7 @@ EXTERN int COMPINDEX[MAX_ALENGTH+1];
 }
 
 //
-// Compute the p-value of a set of sites and round it to RNDDIG places.
+// Compute the p-value of a set of sites and round it to STREME_RND places.
 //
 #define GET_PVALUE(log_pvalue, objfun, use_binomial, pos_count, neg_count, npos, nneg, bernoulli, dtc_sum, w, len, text, cache, cache_length) \
   { \
@@ -546,6 +545,8 @@ typedef struct options {
   BOOL text_only;			// output text only; don't create directory
   char *posfile;			// positive sequences filename
   char *negfile;			// negative sequences filename
+  BOOL parse_genomic_coord;		// parse genomic coord in primary sequence headers
+  BOOL notrim;				// do not trim control sequences
   int totallength;			// truncate each sequence set (+/-) to this length
   OBJFUN_T objfun;			// objective function
   int order;				// use this order background model and sequence shuffling
@@ -607,13 +608,13 @@ void shuffle_multiseq(
 Multiseq *read_pos_neg_seqs(
   STREME_OPTIONS_T *options,
   BOOL do_rc,                           // append reverse complement of pos+neg sequences
-                                        // negative sequences by shuffling positive sequences
+  BOOL use_smaller_strand,              // ensure results are independent of strand
   BOOL allow_ambigs,                    // don't convert ambiguous characters to SEPARATOR
   BOOL no_trim,                         // don't trim sequences to average length
   BOOL set_back,                        // set the background in the multiseq objects
   ARRAY_T *background,                  // IN MEME-style background model
   Multiseq **test_multiseq_ptr          // OUT hold-out set
-);
+); 
 
 void set_multiseq_background(
   STREME_OPTIONS_T *options,
@@ -628,7 +629,7 @@ void set_logcumback(
   Multiseq *multiseq
 );
 
-void append_to_multiseq(
+BOOL append_to_multiseq(
   Multiseq *multiseq,           // old sequences
   Multiseq *multiseq2,          // sequences to append
   BOOL no_trim,
@@ -648,7 +649,8 @@ void score_model_pssm(
   SAVE_MATCHES_T save_matches,          // ZOOPS: save best match (sorted) in every sequence (positive or negative) for nesting
                                         // PASSING: save all matches with score >= model->score_threshold for erasing
   BOOL is_ho,                           // data is the hold-out set
-  BOOL use_cache                        // use the p-value cache
+  BOOL use_cache,                        // use the p-value cache
+  BOOL pos_only                         // just score the positive sequences
 );
 
 void get_passing_sequences(
@@ -670,6 +672,11 @@ int compare_site_score(
   const void *v2
 );
 
+int compare_site_seq_pos(
+  const void *v1,
+  const void *v2
+);
+
 int compare_sequence_score(
   const void *v1,
   const void *v2
