@@ -6,7 +6,10 @@
  * COPYRIGHT: 2019, UNR
  ********************************************************************/
 
+#ifdef MAIN
 #define DEFINE_GLOBALS
+#endif
+
 #define _GNU_SOURCE // for asprintf
 #include <assert.h>
 #include <getopt.h>
@@ -75,8 +78,6 @@ const char* TEMPLATE_FILENAME = "tgene_template.html";
 const char* TSV_FILENAME = "tgene.tsv";		// Name of TSV tgene output
 const char* HTML_FILENAME = "tgene.html";	// Name of HTML tgene output
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 // Structure for tracking tgene command line parameters.
 typedef struct options {
   char *locus_file; 		// name of file containing loci
@@ -98,7 +99,7 @@ typedef struct options {
   double lecat;			// scale correlation if maximum expression of transcript < lecat
   int seed;			// random number seed
   char *desc; 			// description of job
-  char *fdesc;			// file containing description
+  char *dfile;			// file containing description
   int n_tissues;		// not an option
   STRING_LIST_T *tissue_names;	// not an option
   int n_histones;		// not an option
@@ -312,7 +313,7 @@ static void usage(bool msg, char *format, ...) {
     "    --seed <seed>                  seed for random number generator for noise and null model\n"
     "                                          default: %d\n"
     "    --desc <text>                  plain text description of the job\n"
-    "    --fdesc <file>                 file containing plain text description of the job\n"
+    "    --dfile <file>                 file containing plain text description of the job\n"
     "    --verbosity 1|2|3|4|5          level of information messages output to terminal\n"
     "    --help                         display the usage message and exit\n"
     "    --version                      show version and exit\n"
@@ -361,6 +362,7 @@ static char *process_command_line(int argc, char* argv[], TGENE_OPTIONS_T *optio
     OPT_NO_NOISE,
     OPT_SEED, 
     OPT_DESC, 
+    OPT_DFILE,
     OPT_FDESC,
     OPT_VERBOSITY, 
     OPT_HELP, 
@@ -384,6 +386,7 @@ static char *process_command_line(int argc, char* argv[], TGENE_OPTIONS_T *optio
     {"no-noise", no_argument, NULL, OPT_NO_NOISE},
     {"seed", required_argument, NULL, OPT_SEED},
     {"desc", required_argument, NULL, OPT_DESC},
+    {"dfile", required_argument, NULL, OPT_DFILE},
     {"fdesc", required_argument, NULL, OPT_FDESC},
     {"verbosity", required_argument, NULL, OPT_VERBOSITY},
     {"help", no_argument, NULL, OPT_HELP},
@@ -411,7 +414,7 @@ static char *process_command_line(int argc, char* argv[], TGENE_OPTIONS_T *optio
   options->no_noise = false;
   options->seed = seed;
   options->desc = NULL;
-  options->fdesc = NULL;
+  options->dfile = NULL;
   verbosity = NORMAL_VERBOSE;
 
   // process arguments
@@ -473,8 +476,9 @@ static char *process_command_line(int argc, char* argv[], TGENE_OPTIONS_T *optio
       case OPT_DESC:
         options->desc = optarg;
         break;
+      case OPT_DFILE:
       case OPT_FDESC:
-        options->fdesc = optarg;
+        options->dfile = optarg;
         break;
       case OPT_VERBOSITY:
         verbosity = atoi(optarg);
@@ -790,7 +794,7 @@ static void output_html_file(
   jsonwr_end_object_value(json);
 
   // Output description
-  jsonwr_desc_prop(json, "job_description", options->fdesc, options->desc);
+  jsonwr_desc_prop(json, "job_description", options->dfile, options->desc);
 
   // Output general information.
   jsonwr_bool_prop(json, "have_tss_info", link_table->have_tss_info);
