@@ -23,6 +23,9 @@
 /* maximum allowable length before shortening */
 #define MAX_W 50
 
+/* maximum number of MEME motifs to find if -evt set */
+#define MAX_NMOTIFS 1000
+
 /* default size of heap for branching search */
 // Don't really need the heaps now that branching search is removed.
 #define HSIZE 64
