@@ -54,6 +54,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
     int minw;
     int maxw;
     public Background background;
+    public boolean pgc;
     // MEME options
     String memeOptMode;
     int memeOptNMotifs;
@@ -63,6 +64,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
     boolean memeOptNorand;	// MEME won't randomize sequence order
     // STREME options
     double stremeOptP;
+    String stremeOptAlign;
     Integer stremeOptM;
     // CentriMo options
     double centrimoOptScore;
@@ -82,6 +84,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
       out.property("minw", minw);
       out.property("maxw", maxw);
       out.property("background", background);
+      out.property("pgc", pgc);
       out.property("memeOptMode", memeOptMode);
       out.property("memeOptNMotifs", memeOptNMotifs);
       if (memeOptMinSites != null) out.property("memeOptMinSites", memeOptMinSites);
@@ -90,6 +93,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
       out.property("memeOptNorand", memeOptNorand);
       if (stremeOptP > 0) out.property("stremeOptP", stremeOptP);
       if (stremeOptM != null) out.property("stremeOptM", stremeOptM);
+      out.property("stremeOptAlign", stremeOptAlign);
       out.property("centrimoOptScore", centrimoOptScore);
       if (centrimoOptMaxReg != null) out.property("centrimoOptMaxReg", centrimoOptMaxReg);
       out.property("centrimoOptEThresh", centrimoOptEThresh);
@@ -147,6 +151,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
       if (negSeq != null) addArgs(args, "-neg", negSeq.getName());
       addArgs(args, "-minw", minw);
       addArgs(args, "-maxw", maxw);
+      if (pgc) addArgs(args, "-parse-genomic-coord");
       // MEME specific arguments
       addArgs(args, "-meme-mod", memeOptMode);
       addArgs(args, "-meme-nmotifs", memeOptNMotifs);
@@ -157,6 +162,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
       // STREME specific options
       if (stremeOptP > 0) addArgs(args, "-streme-pvt", stremeOptP);
       if (stremeOptM != null) addArgs(args, "-streme-nmotifs", stremeOptM);
+      if (stremeOptAlign != null) addArgs(args, "-streme-align", stremeOptAlign);
       // CentriMo specific options
       if (centrimoOptLocal) addArgs(args, "-centrimo-local");
       addArgs(args, "-centrimo-score", centrimoOptScore);
@@ -339,6 +345,7 @@ public class Memechip extends SubmitJob<Memechip.Data> {
     if (data.minw > data.maxw) {
       feedback.whine("The minimum motif width is larger than the maximum motif width.");
     }
+    data.pgc = WebUtils.paramBool(request, "pgc");
     // get the MEME options
     data.memeOptMode = paramChoice(request, "meme_dist", "zoops", "oops", "anr");
     data.memeOptNMotifs = paramInteger(feedback, "MEME number of motifs", request, "meme_nmotifs", 0, null, 3);
@@ -367,6 +374,8 @@ public class Memechip extends SubmitJob<Memechip.Data> {
       data.stremeOptP = paramNumber(feedback, "STREME p-value threshold", request, "streme_pthresh", 0.0, null, 0.05);
       data.stremeOptM = null;
     }
+    // Align
+    data.stremeOptAlign = paramChoice(request, "streme_align", "left", "center", "right");
     // get the CentriMo options
     data.centrimoOptScore = paramNumber(feedback, "CentriMo match score threshold", request, "centrimo_score", null, null, 5.0);
     if (paramBool(request, "centrimo_maxreg_enable")) {
