@@ -51,6 +51,7 @@ public class Xstreme extends SubmitJob<Xstreme.Data> {
     public Integer order;
     public Integer ctrim;
     public String align;
+    public boolean pgc;
     // STREME options
     double stremeOptE;
     Integer stremeOptM;
@@ -75,6 +76,7 @@ public class Xstreme extends SubmitJob<Xstreme.Data> {
       if (order != null) out.property("order", order);
       if (ctrim != null) out.property("ctrim", ctrim);
       if (align != null) out.property("align", align);
+      out.property("pgc", pgc);
       out.property("background", background);
       if (stremeOptE > 0) out.property("stremeOptE", stremeOptE);
       if (stremeOptM != null) out.property("stremeOptM", stremeOptM);
@@ -132,6 +134,7 @@ public class Xstreme extends SubmitJob<Xstreme.Data> {
       if (evt > 0) addArgs(args, "-evt", evt);
       addArgs(args, "-minw", minw);
       addArgs(args, "-maxw", maxw);
+      if (pgc) addArgs(args, "-parse-genomic-coord");
       // STREME specific options
       if (stremeOptE > 0) addArgs(args, "-streme-evt", stremeOptE);
       if (stremeOptM != null) addArgs(args, "-streme-nmotifs", stremeOptM);
@@ -308,6 +311,7 @@ public class Xstreme extends SubmitJob<Xstreme.Data> {
       // Align
       data.align = paramChoice(request, "align", "left", "center", "right");
       data.background = background.getBfile(backgroundName, request, feedback);
+      data.pgc = WebUtils.paramBool(request, "pgc");
       // get the STREME options
       if ("streme_enable_ethresh".equals(paramOption(request, "streme_srch_limit", "default"))) {
 	data.stremeOptE = paramNumber(feedback, "STREME E-value threshold", request, "streme_ethresh", 0.0, null, 0.05);
