@@ -25,7 +25,6 @@ import java.util.regex.Pattern;
  * Downloads genomes from GenBank in the specified groupings.
  */
 public class GenbankUpdater extends SequenceUpdater {
-  private static Logger logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.genbank");
   private static final int GENBANK_RETRIEVER_ID = 3;
   private static Pattern releaseNumPattern = Pattern.compile("^\\s*(\\d+)\\s*$");
   private static final int RETRY_COUNT = 3;
@@ -33,20 +32,29 @@ public class GenbankUpdater extends SequenceUpdater {
   private String host;
   private String path;
   private String ftpLog;
-  private String[] groups;
   private int retain;
+  private String categoryName;
+  private String dbSubdir;
+  private String ftpSubdir;
+  private Logger logger;
 
-  public GenbankUpdater(SQLiteDataSource dataSource,
+  public GenbankUpdater(String division, SQLiteDataSource dataSource,
       ReentrantReadWriteLock dbLock, File binDir, File dbDir,
       ExecutorService worker, MultiSourceStatus multiStatus) {
     super("GenBank Genome Downloader", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
 
+    // Set the common properties.
     Properties conf = loadConf(GenbankUpdater.class, dbDir, "GenbankUpdater.properties");
     host = conf.getProperty("host", "ftp.ncbi.nih.gov").trim();
     path = conf.getProperty("path", "/genbank/").trim();
     ftpLog = conf.getProperty("ftp.log", "").trim();
-    groups = conf.getProperty("groups", "Bacteria Fungi").trim().split("\\s+");
     retain = getConfInt(conf, "retain", 1, null, 1);
+    // Get the properties specific to this division.
+    categoryName = conf.getProperty(division + "_categoryName", "unknown_categoryName").trim();
+    dbSubdir = conf.getProperty(division + "_dbSubdir", "unknown_dbSubdir").trim();
+    ftpSubdir = conf.getProperty(division + "_ftpSubdir", "unknown_ftpSubdir").trim();
+    logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.genbank." + ftpSubdir);
+    logger.log(Level.INFO, "Genbank division: " + division);
   }
 
   protected int queryReleaseNumber(FTPClient ftp) throws IOException {
@@ -88,17 +96,15 @@ public class GenbankUpdater extends SequenceUpdater {
     int releaseNumber = queryReleaseNumber(ftp);
     logger.log(Level.INFO, "Got release number " + releaseNumber);
     List<GenbankGenome> genomes = new ArrayList<GenbankGenome>();
-    for (String group : groups) {
-      logger.log(Level.INFO, "Looking for class " + group);
-      String genomesPath = path + "genomes/" + group;
-      FTPFile[] genomeDirs = ftp.listDirectories(genomesPath);
-      for (FTPFile genomeDir : genomeDirs) {
-        if (!genomeDir.isDirectory() || genomeDir.getName().equals(".") || genomeDir.getName().equals("..")) continue;
-        String id = genomeDir.getName();
-        String genomePath = genomesPath + "/" + id + "/";
-        genomes.add(new GenbankGenome(releaseNumber, group, id, AlphStd.DNA, genomePath, dna));
-        genomes.add(new GenbankGenome(releaseNumber, group, id, AlphStd.PROTEIN, genomePath, protein));
-      }
+
+    String genomesPath = "genomes/archive/old_genbank/" + ftpSubdir;
+    FTPFile[] genomeDirs = ftp.listDirectories(genomesPath);
+    for (FTPFile genomeDir : genomeDirs) {
+      if (!genomeDir.isDirectory() || genomeDir.getName().equals(".") || genomeDir.getName().equals("..")) continue;
+      String id = genomeDir.getName();
+      String genomePath = genomesPath + "/" + id + "/";
+      genomes.add(new GenbankGenome(releaseNumber, ftpSubdir, id, AlphStd.DNA, genomePath, dna));
+      genomes.add(new GenbankGenome(releaseNumber, ftpSubdir, id, AlphStd.PROTEIN, genomePath, protein));
     }
     return genomes;
   }
@@ -145,31 +151,52 @@ public class GenbankUpdater extends SequenceUpdater {
   public Void call() throws Exception {
     int errorCount = 0;
     FTPClient ftp = null;
-    // get release number from file ftp://ftp.ncbi.nih.gov/genbank/GB_Release_Number
+    File dbTarget;
+
     try {
-      logger.log(Level.INFO, "Starting Genbank update");
+      logger.log(Level.INFO, "categoryName: " + categoryName);
+
+      // Create subdirectory.
+      dbTarget = new File(dbDir + "/" + dbSubdir);
+      logger.log(Level.INFO, "Creating subdirectory for genomes: " + dbTarget);
+      if (!dbTarget.exists() && !dbTarget.mkdir()) {
+        logger.log(Level.SEVERE, "Unable to create subdirectory " + dbTarget + "!");
+        return null;
+      }
+
+      // Login to Genbank FTP site.
       ftp = new FTPClient();
       if (!ftpLog.isEmpty()) {
         ftp.addProtocolCommandListener(new PrintCommandListener(new PrintWriter(new FileOutputStream(ftpLog)), true));
       }
       if (!loginFtp(ftp, host)) return null;
+
+      // Get the list of available genomes.
       List<GenbankGenome> genomes = queryAvailableGenomes(ftp);
       if (genomes.isEmpty()) {
         logger.log(Level.SEVERE, "Failed parsing the genome releases from the FAQ... No genomes found!");
         return null;
       }
+
+      // Query the database to see which genomes we already have
+      // and remove them so we don't download them again.
       progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
-      // query the database to see which genomes we already have
-      // and remove them so we don't download them again
+      int navailable_genomes = 0;
+      int nremoved_genomes = 0;
       Iterator<GenbankGenome> iterator = genomes.iterator();
       while (iterator.hasNext()) {
         GenbankGenome genome = iterator.next();
+        navailable_genomes++;
         if (sourceExists(genome, true)) {
           iterator.remove();
           logger.log(Level.INFO, "Already have " + genome);
+          nremoved_genomes++;
         }
       }
+      logger.log(Level.INFO, "Number of AVAILABLE genomes: " + navailable_genomes);
+      logger.log(Level.INFO, "Number of genomes to UPDATE: " + (navailable_genomes - nremoved_genomes));
       if (genomes.isEmpty()) return null;
+
       genome_loop:
       for (GenbankGenome genome : genomes) {
         try {
@@ -179,7 +206,7 @@ public class GenbankUpdater extends SequenceUpdater {
           for (FtpSource source : genome.getRemoteSources()) {
             if (!downloadFtpSource(ftp, source, true, RETRY_COUNT)) continue genome_loop;
           }
-          enqueueSequences(new GenbankSequenceProcessor(genome));
+          enqueueSequences(new GenbankSequenceProcessor(genome, dbTarget));
         } catch (IOException e) {
           logger.log(Level.WARNING, "Skipped " + genome + " due to ftp errors", e);
           errorCount++;
@@ -190,16 +217,16 @@ public class GenbankUpdater extends SequenceUpdater {
       ftp.disconnect();
       progress.complete();
       waitForWorkerTasks();
-      logger.log(Level.INFO, "Finished Genbank update");
+      logger.log(Level.INFO, "Finished update of " + categoryName);
     } catch (ExecutionException e) { // only thrown by sequence processor
       cancelWorkerTasks();
-      logger.log(Level.SEVERE, "Abandoning GenBank update due to failure to process sequences!", e);
+      logger.log(Level.SEVERE, "Abandoning update of " + dbSubdir + " due to failure to process sequences!", e);
     } catch (SQLException e) {
-      logger.log(Level.SEVERE, "Abandoning GenBank update! Already downloaded sequences will still be processed", e);
+      logger.log(Level.SEVERE, "Abandoning update of " + dbSubdir + "! Already downloaded sequences will still be processed", e);
     } catch (IOException e) {
-      logger.log(Level.SEVERE, "Abandoning GenBank update! Already downloaded sequences will still be processed", e);
+      logger.log(Level.SEVERE, "Abandoning update of " + dbSubdir + "!", e);
     } catch (InterruptedException e) {
-      logger.log(Level.WARNING, "GenBank update interrupted!");
+      logger.log(Level.WARNING, "Update of " + dbSubdir + " was interrupted!", e);
     } catch (RuntimeException e) {
       logger.log(Level.SEVERE, "RuntimeException!", e);
       throw e;
@@ -222,17 +249,19 @@ public class GenbankUpdater extends SequenceUpdater {
 
   private class GenbankSequenceProcessor extends SequenceProcessor {
     private GenbankGenome source;
+    private File dbTarget;
 
-    private GenbankSequenceProcessor(GenbankGenome source) {
+    private GenbankSequenceProcessor(GenbankGenome source, File dbTarget) {
       super(dataSource, dbLock, binDir, dbDir, status);
       this.source = source;
+      this.dbTarget = dbTarget;
     }
 
     @Override
     public void process() throws IOException, SQLException, InterruptedException {
-      if (!unpackSequences(source)) return;
-      processSequences(source);
-      obsoleteOldEditions(recordSequences(source).listingId, source.guessAlphabet(), retain);
+      if (!unpackSequences(source, dbTarget)) return;
+      processSequences(source, dbTarget);
+      obsoleteOldEditions(recordSequences(source, dbTarget, dbSubdir).listingId, source.guessAlphabet(), retain);
     }
   }
 
@@ -352,7 +381,7 @@ public class GenbankUpdater extends SequenceUpdater {
       String name = id;
       name = name.replaceAll("[^a-zA-Z0-9\\p{Z}\\s_\\.-]", "");
       name = name.replaceAll("[\\p{Z}\\s]+", "_");
-      return "genbank_" + name + "_" + version;
+      return name + "_" + version;
     }
 
     public List<File> getSourceFiles() {
@@ -463,7 +492,7 @@ public class GenbankUpdater extends SequenceUpdater {
 
       @Override
       public String getRemoteUrl() {
-        return "ftp://" + getRemoteHost() + getRemotePath();
+        return "ftp://" + getRemoteHost() + "/" + getRemotePath();
       }
 
       public String getRemoteExt() {
