@@ -22,79 +22,49 @@ import java.util.regex.Pattern;
 import java.util.regex.Matcher;
 
 /**
- * Retrieve sequences from RSA Tools.
+ * Download promoters from RSA Tools for specified groupings.
  */
 public class RsatUpdater extends SequenceUpdater {
   private int ageMin;
   private int start;
   private int end;
   private int retain;
-  private Map<String, String> servers;
-  private Map<String, Pattern> taxa;
+  private String categoryName;
+  private String dbSubdir;
+  private String ftpSubdir;
+  private String server;
+  private String group;
+  private Pattern taxare;
+  private Logger logger;
 
-  private static Logger logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.rsat");
+  //private static Logger logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.rsat");
   private static final int RSAT_RETRIEVER_ID = 4;
 
-  public RsatUpdater(SQLiteDataSource dataSource, ReentrantReadWriteLock dbLock,
+  public RsatUpdater(String division, SQLiteDataSource dataSource, ReentrantReadWriteLock dbLock,
       File binDir, File dbDir, ExecutorService worker, MultiSourceStatus multiStatus) {
     super("RSAT Upstream Downloader", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
 
+    // Set global group.
+    group = division.substring(4);
+
+    // Determine directory for WSDL files.
+    String wsdlDir = binDir.getPath().replace("libexec", "share");
+
     Properties conf = SequenceUpdater.loadConf(RsatUpdater.class, dbDir, "RsatUpdater.properties");
     this.ageMin = getConfInt(conf, "age.min", 0, null, 30);
     this.start = getConfInt(conf, "start", null, null, -1000);
     this.end = getConfInt(conf, "end", null, null, 200);
     this.retain = getConfInt(conf, "retain", 1, null, 1);
-    this.servers = new TreeMap<String, String>();
-    for (String key : conf.stringPropertyNames()) {
-      if (key.startsWith("server.") && key.length() > 7) {
-        String serverName = key.substring(7);
-        String serverURL = conf.getProperty(key);
-        this.servers.put(serverName, serverURL);
-      }
-    }
-    // when no servers defined assume default servers
-    if (servers.isEmpty()) {
-      logger.log(Level.INFO, "No RSAT servers in configuration file, using defaults.");
-      Properties defaultConf = new Properties();
-      try {
-        defaultConf.load(RsatUpdater.class.getResourceAsStream("RsatUpdater.properties"));
-        for (String key : defaultConf.stringPropertyNames()) {
-          if (key.startsWith("server.") && key.length() > 7) {
-            String serverName = key.substring(7);
-            String serverURL = defaultConf.getProperty(key);
-            this.servers.put(serverName, serverURL);
-          }
-        }
-      } catch (IOException e) {
-        logger.log(Level.SEVERE, "Failed to load default configuration file!", e);
-      }
-    }
-    this.taxa = new TreeMap<String, Pattern>();
-    for (String key : conf.stringPropertyNames()) {
-      if (key.startsWith("taxa.") && key.length() > 5) {
-        String taxaName = key.substring(5);
-        String taxaRegex = conf.getProperty(key);
-        this.taxa.put(taxaName, Pattern.compile(taxaRegex.trim()));
-      }
-    }
-    // when no taxa defined assume default taxa
-    if (taxa.isEmpty()) {
-      logger.log(Level.INFO, "No RSAT taxa in configuration file, using defaults.");
-      Properties defaultConf = new Properties();
-      try {
-        defaultConf.load(RsatUpdater.class.getResourceAsStream("RsatUpdater.properties"));
-        for (String key : defaultConf.stringPropertyNames()) {
-          if (key.startsWith("taxa.") && key.length() > 5) {
-            String taxaName = key.substring(5);
-            String taxaRegex = defaultConf.getProperty(key);
-            this.taxa.put(taxaName, Pattern.compile(taxaRegex.trim()));
-            //System.out.println("Taxa " + taxaRegex.trim());
-          }
-        }
-      } catch (IOException e) {
-        logger.log(Level.SEVERE, "Failed to load default configuration file!", e);
-      }
-    }
+    categoryName = conf.getProperty(division + "_categoryName", "unknown_categoryName").trim();
+    dbSubdir = conf.getProperty(division + "_dbSubdir", "unknown_dbSubdir").trim();
+    ftpSubdir = conf.getProperty(division + "_ftpSubdir", "unknown_ftpSubdir").trim();
+    server = wsdlDir + "/" + conf.getProperty(division + "_server", "unknown_server").trim();
+    taxare = Pattern.compile(conf.getProperty(division + "_taxa", "unknown_taxa").trim());
+    logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.rsat." + ftpSubdir);
+    String taxas = conf.getProperty(division + "_taxa", "unknown_taxa").trim();
+    logger.log(Level.INFO, "RSAT division: " + division + " taxa: " + taxas);
+    logger.log(Level.INFO, "wsdlDir: " + wsdlDir);
+
   }
 
   private class StoreErrorMessage extends Thread {
@@ -159,6 +129,7 @@ public class RsatUpdater extends SequenceUpdater {
     }
     public void run() {
       BufferedReader in = null;
+      //System.out.println("\nIn RsatSupportedOrganisms serverName: " + serverName + " serverURL: " + serverURL + "\n");
       try {
         in = new BufferedReader(new InputStreamReader(stream));
         String line;
@@ -167,18 +138,14 @@ public class RsatUpdater extends SequenceUpdater {
           if (parts.length == 2) {
 	    String organism = parts[0];
 	    String taxonomy = parts[1];
-            //System.out.println(organism + " " + taxonomy);
-            String taxon = "Other";
-            for (Map.Entry<String, Pattern> entry : taxa.entrySet()) {
-              Pattern pattern = entry.getValue();
-              Matcher matcher = pattern.matcher(taxonomy);
-              if (matcher.find()) {
-                taxon = entry.getKey();
-                break;
-              }
-            }
-            if (!organism.isEmpty()) sources.add(new RsatSource(serverName, serverURL, organism, taxon, timestamp, start, end));
-          }
+            String taxon;
+	    Pattern pattern = taxare;
+	    Matcher matcher = pattern.matcher(taxonomy);
+	    if (matcher.find()) {
+	      taxon = group;
+	      sources.add(new RsatSource(serverName, serverURL, organism, taxon, timestamp, start, end));
+	    }
+	  }
         }
         in.close(); in = null;
       } catch (IOException e) {
@@ -313,43 +280,46 @@ public class RsatUpdater extends SequenceUpdater {
 
   @Override
   public Void call() throws Exception {
-    try {
-      logger.log(Level.INFO, "Starting RSAT update");
-      for (Map.Entry<String,String> server : this.servers.entrySet()) {
-        logger.log(Level.INFO, "Querying RSAT " + server.getKey() + " server at URL " + server.getValue());
-        List<RsatSource> serverGenomes = queryAvailableOrganisms(server.getKey(), server.getValue());
-        if (serverGenomes.isEmpty()) {
-          logger.log(Level.WARNING, "Empty supported organism list from RSAT " + server.getKey() +
-              " at URL " + server.getValue());
-          continue;
-        } else {
-          logger.log(Level.INFO, "RSAT " + server.getKey() + " at URL " + server.getValue() + " lists " +
-              serverGenomes.size() + " supported organisms; the last one is " +
-              serverGenomes.get(serverGenomes.size() - 1).getOrganism());
-        }
-        progress.setTask("Excluding Pre-exisiting " + server.getKey() + " upstream sequences", 0, -1);
-        // query the database to see which organisms we already have
-        // and remove them so we don't download them again
-        long updateDelayMillis = TimeUnit.DAYS.toMillis(ageMin);
-        Iterator<RsatSource> iterator = serverGenomes.iterator();
-        while (iterator.hasNext()) {
-          RsatSource genome = iterator.next();
-          if (sourceExists(genome, true, false, updateDelayMillis)) {
-            iterator.remove();
-            logger.log(Level.INFO, "Already updated " + genome + " within " + ageMin + " day(s) ago.");
-          }
-        }
-        if (serverGenomes.isEmpty()) continue;
+    File dbTarget;
 
-        for (RsatSource source : serverGenomes) {
-          if (Thread.currentThread().isInterrupted()) throw new InterruptedException();
-          checkWorkerTasks();
-          if (downloadSequence(source)) enqueueSequences(new RsatSequenceProcessor(source));
-        }
-//FIXME
-        //for (RsatSource source : serverGenomes) {
-        //  System.out.println(source.getCategoryName() + " " + source.getOrganism());
-        //}
+    try {
+      logger.log(Level.INFO, "categoryName: " + categoryName);
+
+      // Create subdirectory.
+      dbTarget = new File(dbDir + "/" + dbSubdir);
+      logger.log(Level.INFO, "Creating subdirectory for genomes: " + dbTarget);
+      if (!dbTarget.exists() && !dbTarget.mkdir()) {
+        logger.log(Level.SEVERE, "Unable to create subdirectory " + dbTarget + "!");
+        return null;
+      }
+
+      logger.log(Level.INFO, "Querying RSAT " + group + " server at URL " + server);
+      List<RsatSource> serverGenomes = queryAvailableOrganisms(group, server);
+      if (serverGenomes.isEmpty()) {
+	logger.log(Level.WARNING, "Empty supported organism list from RSAT " + group +
+	  " at URL " + server);
+      } else {
+	logger.log(Level.INFO, "RSAT " + group + " at URL " + server + " lists " +
+	    serverGenomes.size() + " supported organisms; the last one is " +
+	    serverGenomes.get(serverGenomes.size() - 1).getOrganism());
+      }
+      progress.setTask("Excluding Pre-exisiting " + group + " upstream sequences", 0, -1);
+      // Query the database to see which organisms we already have
+      // and remove them so we don't download them again.
+      long updateDelayMillis = TimeUnit.DAYS.toMillis(ageMin);
+      Iterator<RsatSource> iterator = serverGenomes.iterator();
+      while (iterator.hasNext()) {
+	RsatSource genome = iterator.next();
+	if (sourceExists(genome, true, false, updateDelayMillis)) {
+	  iterator.remove();
+	  logger.log(Level.INFO, "Already updated " + genome + " within " + ageMin + " day(s) ago.");
+	}
+      }
+
+      for (RsatSource source : serverGenomes) {
+	if (Thread.currentThread().isInterrupted()) throw new InterruptedException();
+	checkWorkerTasks();
+	if (downloadSequence(source)) enqueueSequences(new RsatSequenceProcessor(source, dbTarget));
       }
       progress.complete();
       waitForWorkerTasks();
@@ -377,15 +347,17 @@ public class RsatUpdater extends SequenceUpdater {
 
   private class RsatSequenceProcessor extends SequenceProcessor {
     private RsatSource source;
+    private File dbTarget;
 
-    public RsatSequenceProcessor(RsatSource source) {
+    public RsatSequenceProcessor(RsatSource source, File dbTarget) {
       super(dataSource, dbLock, binDir, dbDir, status);
       this.source = source;
+      this.dbTarget = dbTarget;
     }
 
-    private void moveSequence(RsatSource source) throws IOException {
+    private void moveSequence(RsatSource source, File dbTarget) throws IOException {
       File sourceFile = source.getSourceFiles().get(0);
-      File sequenceFile = new File(dbDir, source.getLocalName());
+      File sequenceFile = new File(dbTarget, source.getLocalName());
       if (!sourceFile.renameTo(sequenceFile)) {
         throw new IOException("Failed to rename \"" + sourceFile +
             "\" to \"" + sequenceFile + "\"");
@@ -395,9 +367,9 @@ public class RsatUpdater extends SequenceUpdater {
 
     @Override
     public void process() throws IOException, SQLException, InterruptedException {
-      moveSequence(source);
-      processSequences(source);
-      obsoleteOldEditions(recordSequences(source).listingId, source.guessAlphabet(), retain);
+      moveSequence(source, dbTarget);
+      processSequences(source, dbTarget);
+      obsoleteOldEditions(recordSequences(source, dbTarget, dbSubdir).listingId, source.guessAlphabet(), retain);
     }
   }
 
@@ -460,8 +432,7 @@ public class RsatUpdater extends SequenceUpdater {
 
     @Override
     public String getCategoryName() {
-      //return taxon +  " Upstream Sequences";
-      return "Upstream Sequences: " + taxon;
+      return "Upstream Sequences: " + taxon.substring(0,1).toUpperCase() + taxon.substring(1);
     }
 
     @Override
@@ -506,7 +477,7 @@ public class RsatUpdater extends SequenceUpdater {
     public String getNamePrefix() {
       SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
       String when = df.format(new Date(timestamp));
-      return "upstream_" + taxon + "_" + organism + "_" + when;
+      return "upstream_" + start + "_" + end + "_" + organism + "_" + when;
     }
 
     public void setSourceFile(File file) {
